"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPainterPathStroker(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpainterpathstroker.html

    **Detailed Description**

    By calling the **createStroke** () function, passing a given
    **QPainterPath**  as argument, a new painter path representing the outline
    of the given path is created. The newly created painter path can then be
    filled to draw the original painter path's outline.

    You can control the various design aspects (width, cap styles, join styles
    and dash pattern) of the outlining using the following functions:

    * **setWidth** ()
      * **setCapStyle** ()
      * **setJoinStyle** ()
      *
    **setDashPattern** ()

    The **setDashPattern** () function accepts both a **Qt::PenStyle**  object
    and a list representation of the pattern as argument.

    In addition you can specify a curve's threshold, controlling the granularity
    with which a curve is drawn, using the **setCurveThreshold** () function.
    The default threshold is a well adjusted value (0.25), and normally you
    should not need to modify it. However, you can make the curve's appearance
    smoother by decreasing its value.

    You can also control the miter limit for the generated outline using the
    **setMiterLimit** () function. The miter limit describes how far from each
    join the miter join can extend. The limit is specified in the units of width
    so the pixelwise miter limit will be `miterlimit * width`. This value is
    only used if the join style is **Qt::MiterJoin** .

    The painter path generated by the **createStroke** () function should only
    be used for outlining the given painter path. Otherwise it may cause
    unexpected behavior. Generated outlines also require the **Qt::WindingFill**
    rule which is set by default.

    **See also** **QPen**  and **QBrush** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#QPainterPathStroker

        **QPainterPathStroker::QPainterPathStroker()**

        Creates a new stroker.
        """
        ...

    @typing.overload
    def __init__(
        self, pen: typing.Union["QPen", QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#QPainterPathStroker-1

        **[since 5.3] QPainterPathStroker::QPainterPathStroker(const QPen & pen
        )**

        Creates a new stroker based on **pen**.

        This function was introduced in Qt 5.3.
        """
        ...

    def dashOffset(self) -> float:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#dashOffset

        **qreal QPainterPathStroker::dashOffset() const**

        Returns the dash offset for the generated outlines.

        **See also** **setDashOffset** ().
        """
        ...

    def setDashOffset(self, offset: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#setDashOffset

        **void QPainterPathStroker::setDashOffset(qreal offset )**

        Sets the dash offset for the generated outlines to **offset**.

        See the documentation for **QPen::setDashOffset** () for a description
        of the dash offset.

        **See also** **dashOffset** ().
        """
        ...

    def createStroke(self, path: QPainterPath) -> QPainterPath:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#createStroke

        **QPainterPath QPainterPathStroker::createStroke(const QPainterPath &
        path ) const**

        Generates a new path that is a fillable area representing the outline of
        the given **path**.

        The various design aspects of the outline are based on the stroker's
        properties: **width** (), **capStyle** (), **joinStyle** (),
        **dashPattern** (), **curveThreshold** () and **miterLimit** ().

        The generated path should only be used for outlining the given painter
        path. Otherwise it may cause unexpected behavior. Generated outlines
        also require the **Qt::WindingFill**  rule which is set by default.
        """
        ...

    def dashPattern(self) -> typing.List[float]:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#dashPattern

        **QList<qreal> QPainterPathStroker::dashPattern() const**

        Returns the dash pattern for the generated outlines.

        **See also** **setDashPattern** ().
        """
        ...

    @typing.overload
    def setDashPattern(self, a0: QtCore.Qt.PenStyle) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#setDashPattern

        **void QPainterPathStroker::setDashPattern(Qt::PenStyle style )**

        Sets the dash pattern for the generated outlines to **style**.

        **See also** **dashPattern** ().
        """
        ...

    @typing.overload
    def setDashPattern(self, dashPattern: typing.Iterable[float]) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#setDashPattern-1

        **void QPainterPathStroker::setDashPattern(const QList<qreal> &
        dashPattern )**

        This is an overloaded function.

        Sets the dash pattern for the generated outlines to **dashPattern**.
        This function makes it possible to specify custom dash patterns.

        Each element in the list contains the lengths of the dashes and spaces
        in the stroke, beginning with the first dash in the first element, the
        first space in the second element, and alternating between dashes and
        spaces for each following pair of elements.

        The list can contain an odd number of elements, in which case the last
        element will be extended by the length of the first element when the
        pattern repeats.
        """
        ...

    def curveThreshold(self) -> float:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#curveThreshold

        **qreal QPainterPathStroker::curveThreshold() const**

        Returns the curve flattening threshold for the generated outlines.

        **See also** **setCurveThreshold** ().
        """
        ...

    def setCurveThreshold(self, threshold: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#setCurveThreshold

        **void QPainterPathStroker::setCurveThreshold(qreal threshold )**

        Specifies the curve flattening **threshold** , controlling the
        granularity with which the generated outlines' curve is drawn.

        The default threshold is a well adjusted value (0.25), and normally you
        should not need to modify it. However, you can make the curve's
        appearance smoother by decreasing its value.

        **See also** **curveThreshold** ().
        """
        ...

    def miterLimit(self) -> float:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#miterLimit

        **qreal QPainterPathStroker::miterLimit() const**

        Returns the miter limit for the generated outlines.

        **See also** **setMiterLimit** ().
        """
        ...

    def setMiterLimit(self, length: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#setMiterLimit

        **void QPainterPathStroker::setMiterLimit(qreal limit )**

        Sets the miter limit of the generated outlines to **limit**.

        The miter limit describes how far from each join the miter join can
        extend. The limit is specified in units of the currently set width. So
        the pixelwise miter limit will be `miterlimit * width`.

        This value is only used if the join style is **Qt::MiterJoin** .

        **See also** **miterLimit** ().
        """
        ...

    def joinStyle(self) -> QtCore.Qt.PenJoinStyle:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#joinStyle

        **Qt::PenJoinStyle QPainterPathStroker::joinStyle() const**

        Returns the join style of the generated outlines.

        **See also** **setJoinStyle** ().
        """
        ...

    def setJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#setJoinStyle

        **void QPainterPathStroker::setJoinStyle(Qt::PenJoinStyle style )**

        Sets the join style of the generated outlines to **style**.

        **See also** **joinStyle** ().
        """
        ...

    def capStyle(self) -> QtCore.Qt.PenCapStyle:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#capStyle

        **Qt::PenCapStyle QPainterPathStroker::capStyle() const**

        Returns the cap style of the generated outlines.

        **See also** **setCapStyle** ().
        """
        ...

    def setCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#setCapStyle

        **void QPainterPathStroker::setCapStyle(Qt::PenCapStyle style )**

        Sets the cap style of the generated outlines to **style**. If a dash
        pattern is set, each segment of the pattern is subject to the cap
        **style**.

        **See also** **capStyle** ().
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#width

        **qreal QPainterPathStroker::width() const**

        Returns the width of the generated outlines.

        **See also** **setWidth** ().
        """
        ...

    def setWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qpainterpathstroker.html#setWidth

        **void QPainterPathStroker::setWidth(qreal width )**

        Sets the width of the generated outline painter path to **width**.

        The generated outlines will extend approximately 50% of **width** to
        each side of the given input path's original outline.

        **See also** **width** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QQuickTextDocument(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qquicktextdocument.html

    **Detailed Description**

    This class provides access to the **QTextDocument**  of QQuickTextEdit
    elements. This is provided to allow usage of the **Rich Text Processing**
    functionalities of Qt. You are not allowed to modify the document, but it
    can be used to output content, for example with **QTextDocumentWriter** ),
    or provide additional formatting, for example with **QSyntaxHighlighter** .

    The class has to be used from C++ directly, using the property of the
    **TextEdit** .

    Warning: The **QTextDocument**  provided is used internally by **Qt Quick**
    elements to provide text manipulation primitives. You are not allowed to
    perform any modification of the internal state of the **QTextDocument** . If
    you do, the element in question may stop functioning or crash.
    """

    def __init__(self, parent: QQuickItem) -> None:
        """
        https://doc.qt.io/qt-6/qquicktextdocument.html#QQuickTextDocument

        **QQuickTextDocument::QQuickTextDocument(QQuickItem * parent )**

        Constructs a QQuickTextDocument object with **parent** as the parent
        object.
        """
        ...

    def textDocument(self) -> QtGui.QTextDocument:
        """
        https://doc.qt.io/qt-6/qquicktextdocument.html#textDocument

        **QTextDocument *QQuickTextDocument::textDocument() const**

        Returns a pointer to the **QTextDocument**  object.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDnsMailExchangeRecord(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdnsmailexchangerecord.html

    **Detailed Description**

    When performing a lookup on a service, zero or more records will be
    returned. Each record is represented by a QDnsMailExchangeRecord instance.

    The meaning of the fields is defined in **RFC 1035** .

    **See also** **QDnsLookup** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdnsmailexchangerecord.html#QDnsMailExchangeRecor
        d

        **QDnsMailExchangeRecord::QDnsMailExchangeRecord()**

        Constructs an empty mail exchange record object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDnsMailExchangeRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnsmailexchangerecord.html#QDnsMailExchangeRecor
        d-1

        **QDnsMailExchangeRecord::QDnsMailExchangeRecord(const
        QDnsMailExchangeRecord & other )**

        Constructs a copy of **other**.
        """
        ...

    def timeToLive(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnsmailexchangerecord.html#timeToLive

        **quint32 QDnsMailExchangeRecord::timeToLive() const**

        Returns the duration in seconds for which this record is valid.
        """
        ...

    def preference(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnsmailexchangerecord.html#preference

        **quint16 QDnsMailExchangeRecord::preference() const**

        Returns the preference for this record.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdnsmailexchangerecord.html#name

        **QString QDnsMailExchangeRecord::name() const**

        Returns the name for this record.
        """
        ...

    def exchange(self) -> str:
        """
        https://doc.qt.io/qt-6/qdnsmailexchangerecord.html#exchange

        **QString QDnsMailExchangeRecord::exchange() const**

        Returns the domain name of the mail exchange for this record.
        """
        ...

    def swap(self, other: "QDnsMailExchangeRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnsmailexchangerecord.html#swap

        **void QDnsMailExchangeRecord::swap(QDnsMailExchangeRecord & other )**

        Swaps this mail exchange record with **other**. This function is very
        fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QGeoAddress import QGeoAddress as QGeoAddress
from ._QGeoAreaMonitorInfo import QGeoAreaMonitorInfo as QGeoAreaMonitorInfo
from ._QGeoAreaMonitorSource import QGeoAreaMonitorSource as QGeoAreaMonitorSource
from ._QGeoShape import QGeoShape as QGeoShape
from ._QGeoCircle import QGeoCircle as QGeoCircle
from ._QGeoCoordinate import QGeoCoordinate as QGeoCoordinate
from ._QGeoLocation import QGeoLocation as QGeoLocation
from ._QGeoPath import QGeoPath as QGeoPath
from ._QGeoPolygon import QGeoPolygon as QGeoPolygon
from ._QGeoPositionInfo import QGeoPositionInfo as QGeoPositionInfo
from ._QGeoPositionInfoSource import QGeoPositionInfoSource as QGeoPositionInfoSource
from ._QGeoRectangle import QGeoRectangle as QGeoRectangle
from ._QGeoSatelliteInfo import QGeoSatelliteInfo as QGeoSatelliteInfo
from ._QGeoSatelliteInfoSource import QGeoSatelliteInfoSource as QGeoSatelliteInfoSource
from ._QNmeaPositionInfoSource import QNmeaPositionInfoSource as QNmeaPositionInfoSource
from ._QNmeaSatelliteInfoSource import (
    QNmeaSatelliteInfoSource as QNmeaSatelliteInfoSource,
)



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore


class QGraphicsTransform(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qgraphicstransform.html

    **Detailed Description**

    As an alternative to **QGraphicsItem::transform** , QGraphicsTransform lets
    you create and control advanced transformations that can be configured
    independently using specialized properties.

    **QGraphicsItem**  allows you to assign any number of QGraphicsTransform
    instances to one **QGraphicsItem** . Each QGraphicsTransform is applied in
    order, one at a time, to the **QGraphicsItem**  it's assigned to.

    QGraphicsTransform is particularly useful for animations. Whereas
    **QGraphicsItem::setTransform** () lets you assign any transform directly to
    an item, there is no direct way to interpolate between two different
    transformations (e.g., when transitioning between two states, each for which
    the item has a different arbitrary transform assigned). Using
    QGraphicsTransform you can interpolate the property values of each
    independent transformation. The resulting operation is then combined into a
    single transform which is applied to **QGraphicsItem** .

    Transformations are computed in true 3D space using **QMatrix4x4** . When
    the transformation is applied to a **QGraphicsItem** , it will be projected
    back to a 2D **QTransform** . When multiple QGraphicsTransform objects are
    applied to a **QGraphicsItem** , all of the transformations are computed in
    true 3D space, with the projection back to 2D only occurring after the last
    QGraphicsTransform is applied. The exception to this is
    **QGraphicsRotation** , which projects back to 2D after each rotation to
    preserve the perspective effect around the X and Y axes.

    If you want to create your own configurable transformation, you can create a
    subclass of QGraphicsTransform (or any or the existing subclasses), and
    reimplement the pure virtual **applyTo** () function, which takes a pointer
    to a **QMatrix4x4** . Each operation you would like to apply should be
    exposed as properties (e.g., customTransform->setVerticalShear(2.5)). Inside
    you reimplementation of **applyTo** (), you can modify the provided
    transform respectively.

    QGraphicsTransform can be used together with **QGraphicsItem::setTransform**
    (), **QGraphicsItem::setRotation** (), and **QGraphicsItem::setScale** ().

    **See also** **QGraphicsItem::transform** (), **QGraphicsScale** , and
    **QGraphicsRotation** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstransform.html#QGraphicsTransform

        **QGraphicsTransform::QGraphicsTransform(QObject * parent = nullptr)**

        Constructs a new QGraphicsTransform with the given **parent**.
        """
        ...

    def update(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstransform.html#update

        **[protected slot] void QGraphicsTransform::update()**

        Notifies that this transform operation has changed its parameters in
        such a way that **applyTo** () will return a different result than
        before.

        When implementing you own custom graphics transform, you must call this
        function every time you change a parameter, to let **QGraphicsItem**
        know that its transformation needs to be updated.

        **See also** **applyTo** ().
        """
        ...

    def applyTo(self, matrix: QtGui.QMatrix4x4) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstransform.html#applyTo

        **[pure virtual] void QGraphicsTransform::applyTo(QMatrix4x4 * matrix )
        const**

        This pure virtual method has to be reimplemented in derived classes.

        It applies this transformation to **matrix**.

        **See also** **QGraphicsItem::transform** () and
        **QMatrix4x4::toTransform** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *


class QLowEnergyCharacteristicData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html

    **Detailed Description**

    An Object of this class provides a characteristic to be added to a
    **QLowEnergyServiceData**  object via
    **QLowEnergyServiceData::addCharacteristic** ().

    **See also** **QLowEnergyServiceData**  and
    **QLowEnergyController::addService** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#QLowEnergyChara
        cteristicData

        **QLowEnergyCharacteristicData::QLowEnergyCharacteristicData()**

        Creates a new invalid object of this class.
        """
        ...

    @typing.overload
    def __init__(self, other: "QLowEnergyCharacteristicData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#QLowEnergyChara
        cteristicData-1

        **QLowEnergyCharacteristicData::QLowEnergyCharacteristicData(const
        QLowEnergyCharacteristicData & other )**

        Constructs a new object of this class that is a copy of **other**.
        """
        ...

    def swap(self, other: "QLowEnergyCharacteristicData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#swap

        **void QLowEnergyCharacteristicData::swap(QLowEnergyCharacteristicData &
        other )**

        Swaps this object with **other**.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#isValid

        **bool QLowEnergyCharacteristicData::isValid() const**

        Returns true if and only if this characteristic is valid, that is, it
        has a non-null UUID.
        """
        ...

    def maximumValueLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#maximumValueLen
        gth

        **int QLowEnergyCharacteristicData::maximumValueLength() const**

        Returns the maximum length in bytes that the value of this
        characteristic can have. By default, there is no limit beyond the
        constraints of the data type.
        """
        ...

    def minimumValueLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#minimumValueLen
        gth

        **int QLowEnergyCharacteristicData::minimumValueLength() const**

        Returns the minimum length in bytes that the value of this
        characteristic can have. The default is zero.
        """
        ...

    def setValueLength(self, minimum: int, maximum: int) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#setValueLength

        **void QLowEnergyCharacteristicData::setValueLength(int minimum , int
        maximum )**

        Specifies **minimum** and **maximum** to be the smallest and largest
        length, respectively, that the value of this characteristic can have.
        The unit is bytes. If **minimum** and **maximum** are equal, the
        characteristic has a fixed-length value.
        """
        ...

    def writeConstraints(self) -> QBluetooth.AttAccessConstraint:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#writeConstraint
        s

        **QBluetooth::AttAccessConstraints
        QLowEnergyCharacteristicData::writeConstraints() const**

        Returns the constraints needed for a client to write the value of this
        characteristic. If **properties** () does not include either of
        **QLowEnergyCharacteristic::Write** ,
        **QLowEnergyCharacteristic::WriteNoResponse**  and
        **QLowEnergyCharacteristic::WriteSigned** , this value is irrelevant. By
        default, there are no write constraints.

        **See also** **setWriteConstraints** ().
        """
        ...

    def setWriteConstraints(self, constraints: QBluetooth.AttAccessConstraint) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#setWriteConstra
        ints

        **void QLowEnergyCharacteristicData::setWriteConstraints(QBluetooth::Att
        AccessConstraints constraints )**

        Specifies that clients need to fulfill **constraints** to write the
        value of this characteristic.

        **See also** **writeConstraints** ().
        """
        ...

    def readConstraints(self) -> QBluetooth.AttAccessConstraint:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#readConstraints

        **QBluetooth::AttAccessConstraints
        QLowEnergyCharacteristicData::readConstraints() const**

        Returns the constraints needed for a client to read the value of this
        characteristic. If **properties** () does not include
        **QLowEnergyCharacteristic::Read** , this value is irrelevant. By
        default, there are no read constraints.

        **See also** **setReadConstraints** ().
        """
        ...

    def setReadConstraints(self, constraints: QBluetooth.AttAccessConstraint) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#setReadConstrai
        nts

        **void QLowEnergyCharacteristicData::setReadConstraints(QBluetooth::AttA
        ccessConstraints constraints )**

        Specifies that clients need to fulfill **constraints** to read the value
        of this characteristic.

        **See also** **readConstraints** ().
        """
        ...

    def addDescriptor(self, descriptor: "QLowEnergyDescriptorData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#addDescriptor

        **void QLowEnergyCharacteristicData::addDescriptor(const
        QLowEnergyDescriptorData & descriptor )**

        Adds **descriptor** to the list of descriptors of this characteristic,
        if it is valid.

        **See also** **setDescriptors** ().
        """
        ...

    def setDescriptors(
        self, descriptors: typing.Iterable["QLowEnergyDescriptorData"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#setDescriptors

        **void QLowEnergyCharacteristicData::setDescriptors(const
        QList<QLowEnergyDescriptorData> & descriptors )**

        Sets the descriptors of this characteristic to **descriptors**. Only
        valid descriptors are considered.

        **See also** **descriptors** () and **addDescriptor** ().
        """
        ...

    def descriptors(self) -> typing.List["QLowEnergyDescriptorData"]:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#descriptors

        **QList<QLowEnergyDescriptorData>
        QLowEnergyCharacteristicData::descriptors() const**

        Returns the descriptors of this characteristic.

        **See also** **setDescriptors** ().
        """
        ...

    def setProperties(self, properties: QLowEnergyCharacteristic.PropertyType) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#setProperties

        **void QLowEnergyCharacteristicData::setProperties(QLowEnergyCharacteris
        tic::PropertyTypes properties )**

        Sets the properties of this characteristic to **properties**.

        **See also** **properties** ().
        """
        ...

    def properties(self) -> QLowEnergyCharacteristic.PropertyType:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#properties

        **QLowEnergyCharacteristic::PropertyTypes
        QLowEnergyCharacteristicData::properties() const**

        Returns the properties of this characteristic.

        **See also** **setProperties** ().
        """
        ...

    def setValue(self, value: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#setValue

        **void QLowEnergyCharacteristicData::setValue(const QByteArray & value
        )**

        Sets the value of this characteristic to **value**.

        **See also** **value** ().
        """
        ...

    def value(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#value

        **QByteArray QLowEnergyCharacteristicData::value() const**

        Returns the value of this characteristic.

        **See also** **setValue** ().
        """
        ...

    def setUuid(self, uuid: QBluetoothUuid) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#setUuid

        **void QLowEnergyCharacteristicData::setUuid(const QBluetoothUuid & uuid
        )**

        Sets the UUID of this characteristic to **uuid**.

        **See also** **uuid** ().
        """
        ...

    def uuid(self) -> QBluetoothUuid:
        """
        https://doc.qt.io/qt-6/qlowenergycharacteristicdata.html#uuid

        **QBluetoothUuid QLowEnergyCharacteristicData::uuid() const**

        Returns the UUID of this characteristic.

        **See also** **setUuid** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtCore import *


class QObjectCleanupHandler(QObject):
    """
    https://doc.qt.io/qt-6/qobjectcleanuphandler.html

    **Detailed Description**

    A QObjectCleanupHandler is useful whenever you need to know when a number of
    **QObject** s that are owned by someone else have been deleted. This is
    important, for example, when referencing memory in an application that has
    been allocated in a shared library.

    To keep track of some **QObject** s, create a QObjectCleanupHandler, and
    **add** () the objects you are interested in. If you are no longer
    interested in tracking a particular object, use **remove** () to remove it
    from the cleanup handler. If an object being tracked by the cleanup handler
    gets deleted by someone else it will automatically be removed from the
    cleanup handler. You can delete all the objects in the cleanup handler with
    **clear** (), or by destroying the cleanup handler. **isEmpty** () returns
    `true` if the QObjectCleanupHandler has no objects to keep track of.

    **See also** **QPointer** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qobjectcleanuphandler.html#QObjectCleanupHandler

        **QObjectCleanupHandler::QObjectCleanupHandler()**

        Constructs an empty QObjectCleanupHandler.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qobjectcleanuphandler.html#clear

        **void QObjectCleanupHandler::clear()**

        Deletes all objects in this cleanup handler. The cleanup handler becomes
        empty.

        **See also** **isEmpty** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qobjectcleanuphandler.html#isEmpty

        **bool QObjectCleanupHandler::isEmpty() const**

        Returns `true` if this cleanup handler is empty or if all objects in
        this cleanup handler have been destroyed; otherwise return false.

        **See also** **add** (), **remove** (), and **clear** ().
        """
        ...

    def remove(self, object: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qobjectcleanuphandler.html#remove

        **void QObjectCleanupHandler::remove(QObject * object )**

        Removes the **object** from this cleanup handler. The object will not be
        destroyed.

        **See also** **add** ().
        """
        ...

    def add(self, object: QObject) -> QObject:
        """
        https://doc.qt.io/qt-6/qobjectcleanuphandler.html#add

        **QObject *QObjectCleanupHandler::add(QObject * object )**

        Adds **object** to this cleanup handler and returns the pointer to the
        object.

        **See also** **remove** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QDesktopServices(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdesktopservices.html

    **Detailed Description**

    Many desktop environments provide services that can be used by applications
    to perform common tasks, such as opening a web page, in a way that is both
    consistent and takes into account the user's application preferences.

    This class contains functions that provide simple interfaces to these
    services that indicate whether they succeeded or failed.

    The **openUrl** () function is used to open files located at arbitrary URLs
    in external applications. For URLs that correspond to resources on the local
    filing system (where the URL scheme is "file"), a suitable application will
    be used to open the file; otherwise, a web browser will be used to fetch and
    display the file.

    The user's desktop settings control whether certain executable file types
    are opened for browsing, or if they are executed instead. Some desktop
    environments are configured to prevent users from executing files obtained
    from non-local URLs, or to ask the user's permission before doing so.

    **URL Handlers**

    The behavior of the **openUrl** () function can be customized for individual
    URL schemes to allow applications to override the default handling behavior
    for certain types of URLs.

    The dispatch mechanism allows only one custom handler to be used for each
    URL scheme; this is set using the **setUrlHandler** () function. Each
    handler is implemented as a slot which accepts only a single **QUrl**
    argument.

    The existing handlers for each scheme can be removed with the
    **unsetUrlHandler** () function. This returns the handling behavior for the
    given scheme to the default behavior.

    This system makes it easy to implement a help system, for example. Help
    could be provided in labels and text browsers using
    **help://myapplication/mytopic** URLs, and by registering a handler it
    becomes possible to display the help text inside the application:

    class MyHelpHandler : public **QObject**
        {
            Q_OBJECT
        public:
    // ...
        public slots:
            void showHelp(const **QUrl**  &url);
        };
    **QDesktopServices** ::setUrlHandler("help", helpInstance, "showHelp");

    If inside the handler you decide that you can't open the requested URL, you
    can just call **QDesktopServices::openUrl** () again with the same argument,
    and it will try to open the URL using the appropriate mechanism for the
    user's desktop environment.

    Combined with platform specific settings, the schemes registered by the
    **openUrl** () function can also be exposed to other applications, opening
    up for application deep linking or a very basic URL-based IPC mechanism.

    **See also** **QSystemTrayIcon** , **QProcess** , and **QStandardPaths** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QDesktopServices") -> None:
        ...

    @staticmethod
    def unsetUrlHandler(scheme: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesktopservices.html#unsetUrlHandler

        **[static] void QDesktopServices::unsetUrlHandler(const QString & scheme
        )**

        Removes a previously set URL handler for the specified **scheme**.

        **See also** **setUrlHandler** ().
        """
        ...

    @typing.overload
    @staticmethod
    def setUrlHandler(scheme: str, receiver: QtCore.QObject, method: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesktopservices.html#setUrlHandler

        **[static] void QDesktopServices::setUrlHandler(const QString & scheme ,
        QObject * receiver , const char * method )**

        Sets the handler for the given **scheme** to be the handler **method**
        provided by the **receiver** object.

        This function provides a way to customize the behavior of **openUrl**
        (). If **openUrl** () is called with a URL with the specified **scheme**
        then the given **method** on the **receiver** object is called instead
        of **QDesktopServices**  launching an external application.

        The provided method must be implemented as a slot that only accepts a
        single **QUrl**  argument.

        class MyHelpHandler : public **QObject**
            {
                Q_OBJECT
        public:
                // ...
            public slots:
                void showHelp(const
        **QUrl**  &url);
            };

        If setUrlHandler() is used to set a new handler for a scheme which
        already has a handler, the existing handler is simply replaced with the
        new one. Since **QDesktopServices**  does not take ownership of
        handlers, no objects are deleted when a handler is replaced.

        Note that the handler will always be called from within the same thread
        that calls **QDesktopServices::openUrl** ().

        **iOS**

        To use this function for receiving data from other apps on iOS you also
        need to add the custom scheme to the `CFBundleURLSchemes` list in your
        Info.plist file:

        <key>CFBundleURLTypes</key>
            <array>
                <dict>
        <key>CFBundleURLSchemes</key>
                    <array>
        <string>myapp</string>
                    </array>
                </dict>
            </array>

        For more information, see the Apple Developer Documentation for
        **Defining a Custom URL Scheme for Your App** .

        **Warning:** It is not possible to claim support for some well known URL
        schemes, including http and https. This is only allowed for Universal
        Links.

        To claim support for http and https the above entry in the Info.plist
        file is not allowed. This is only possible when you add your domain to
        the Entitlements file:

        <key>com.apple.developer.associated-domains</key>
            <array>
        <string>applinks:your.domain.com</string>
            </array>

        iOS will search for /.well-known/apple-app-site-association on your
        domain, when the application is installed. If you want to listen to
        `https://your.domain.com/help?topic=ABCDEF` you need to provide the
        following content there:

        {
                "applinks": {
                    "apps": [],
                    "details":
        [{
                        "appIDs" : [ "ABCDE12345.com.example.app" ],
        "components": [{
                            "/": "/help",
        "?": { "topic": "?*"}
                        }]
                    }]
                }
            }

        For more information, see the Apple Developer Documentation for
        **Supporting Associated Domains** .

        **Android**

        To use this function for receiving data from other apps on Android, you
        need to add one or more intent filter to the `activity` in your app
        manifest:

        <intent-filter>
                <action
        android:name="android.intent.action.VIEW" />
                <category
        android:name="android.intent.category.DEFAULT" />
                <category
        android:name="android.intent.category.BROWSABLE" />
                <data
        android:scheme="https" android:host="your.domain.com"
        android:port="1337" android:path="/help"/>
            </intent-filter>

        For more information, see the Android Developer Documentation for
        **Create Deep Links to App Content** .

        To immediately open the corresponding content in your Android app,
        without requiring the user to select the app, you need to verify your
        link. To enable the verification, add an additional parameter to your
        intent filter:

        <intent-filter android:autoVerify="true">

        Android will look for `https://your.domain.com/.well-
        known/assetlinks.json`, when the application is installed. If you want
        to listen to `https://your.domain.com:1337/help`, you need to provide
        the following content there:

        [{
              "relation": ["delegate_permission/common.handle_all_urls"],
        "target": {
                "namespace": "android_app",
                "package_name":
        "com.example.app",
                "sha256_cert_fingerprints":
                ["14:6D:E
        9:83:C5:73:06:50:D8:EE:B9:95:2F:34:FC:64:16:A0:83:42:E6:1D:BE:A8:8A:04:9
        6:B2:3F:CF:44:E5"]
              }
            }]

        For more information, see the Android Developer Documentation for
        **Verify Android App Links** .

        **See also** **openUrl** () and **unsetUrlHandler** ().
        """
        ...

    @typing.overload
    @staticmethod
    def setUrlHandler(
        scheme: str, method: typing.Callable[[QtCore.QUrl], None]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesktopservices.html#setUrlHandler

        **[static] void QDesktopServices::setUrlHandler(const QString & scheme ,
        QObject * receiver , const char * method )**

        Sets the handler for the given **scheme** to be the handler **method**
        provided by the **receiver** object.

        This function provides a way to customize the behavior of **openUrl**
        (). If **openUrl** () is called with a URL with the specified **scheme**
        then the given **method** on the **receiver** object is called instead
        of **QDesktopServices**  launching an external application.

        The provided method must be implemented as a slot that only accepts a
        single **QUrl**  argument.

        class MyHelpHandler : public **QObject**
            {
                Q_OBJECT
        public:
                // ...
            public slots:
                void showHelp(const
        **QUrl**  &url);
            };

        If setUrlHandler() is used to set a new handler for a scheme which
        already has a handler, the existing handler is simply replaced with the
        new one. Since **QDesktopServices**  does not take ownership of
        handlers, no objects are deleted when a handler is replaced.

        Note that the handler will always be called from within the same thread
        that calls **QDesktopServices::openUrl** ().

        **iOS**

        To use this function for receiving data from other apps on iOS you also
        need to add the custom scheme to the `CFBundleURLSchemes` list in your
        Info.plist file:

        <key>CFBundleURLTypes</key>
            <array>
                <dict>
        <key>CFBundleURLSchemes</key>
                    <array>
        <string>myapp</string>
                    </array>
                </dict>
            </array>

        For more information, see the Apple Developer Documentation for
        **Defining a Custom URL Scheme for Your App** .

        **Warning:** It is not possible to claim support for some well known URL
        schemes, including http and https. This is only allowed for Universal
        Links.

        To claim support for http and https the above entry in the Info.plist
        file is not allowed. This is only possible when you add your domain to
        the Entitlements file:

        <key>com.apple.developer.associated-domains</key>
            <array>
        <string>applinks:your.domain.com</string>
            </array>

        iOS will search for /.well-known/apple-app-site-association on your
        domain, when the application is installed. If you want to listen to
        `https://your.domain.com/help?topic=ABCDEF` you need to provide the
        following content there:

        {
                "applinks": {
                    "apps": [],
                    "details":
        [{
                        "appIDs" : [ "ABCDE12345.com.example.app" ],
        "components": [{
                            "/": "/help",
        "?": { "topic": "?*"}
                        }]
                    }]
                }
            }

        For more information, see the Apple Developer Documentation for
        **Supporting Associated Domains** .

        **Android**

        To use this function for receiving data from other apps on Android, you
        need to add one or more intent filter to the `activity` in your app
        manifest:

        <intent-filter>
                <action
        android:name="android.intent.action.VIEW" />
                <category
        android:name="android.intent.category.DEFAULT" />
                <category
        android:name="android.intent.category.BROWSABLE" />
                <data
        android:scheme="https" android:host="your.domain.com"
        android:port="1337" android:path="/help"/>
            </intent-filter>

        For more information, see the Android Developer Documentation for
        **Create Deep Links to App Content** .

        To immediately open the corresponding content in your Android app,
        without requiring the user to select the app, you need to verify your
        link. To enable the verification, add an additional parameter to your
        intent filter:

        <intent-filter android:autoVerify="true">

        Android will look for `https://your.domain.com/.well-
        known/assetlinks.json`, when the application is installed. If you want
        to listen to `https://your.domain.com:1337/help`, you need to provide
        the following content there:

        [{
              "relation": ["delegate_permission/common.handle_all_urls"],
        "target": {
                "namespace": "android_app",
                "package_name":
        "com.example.app",
                "sha256_cert_fingerprints":
                ["14:6D:E
        9:83:C5:73:06:50:D8:EE:B9:95:2F:34:FC:64:16:A0:83:42:E6:1D:BE:A8:8A:04:9
        6:B2:3F:CF:44:E5"]
              }
            }]

        For more information, see the Android Developer Documentation for
        **Verify Android App Links** .

        **See also** **openUrl** () and **unsetUrlHandler** ().
        """
        ...

    @staticmethod
    def openUrl(url: QtCore.QUrl) -> bool:
        """
        https://doc.qt.io/qt-6/qdesktopservices.html#openUrl

        **[static] bool QDesktopServices::openUrl(const QUrl & url )**

        Opens the given **url** in the appropriate Web browser for the user's
        desktop environment, and returns `true` if successful; otherwise returns
        `false`.

        If the URL is a reference to a local file (i.e., the URL scheme is
        "file") then it will be opened with a suitable application instead of a
        Web browser.

        The following example opens a file on the Windows file system residing
        on a path that contains spaces:

        **QDesktopServices** ::openUrl(**QUrl** ("file:///C:/Documents and
        Settings/All Users/Desktop", **QUrl** ::TolerantMode));

        If a `mailto` URL is specified, the user's e-mail client will be used to
        open a composer window containing the options specified in the URL,
        similar to the way `mailto` links are handled by a Web browser.

        For example, the following URL contains a recipient (`user@foo.com`), a
        subject (`Test`), and a message body (`Just a test`):

        mailto:user@foo.com?subject=Test&body=Just a test

        **Warning:** Although many e-mail clients can send attachments and are
        Unicode-aware, the user may have configured their client without these
        features. Also, certain e-mail clients (e.g., Lotus Notes) have problems
        with long URLs.

        **Warning:** A return value of `true` indicates that the application has
        successfully requested the operating system to open the URL in an
        external application. The external application may still fail to launch
        or fail to open the requested URL. This result will not be reported back
        to the application.

        **Warning:** URLs passed to this function on iOS will not load unless
        their schemes are listed in the `LSApplicationQueriesSchemes` key of the
        application's Info.plist file. For more information, see the Apple
        Developer Documentation for **canOpenURL:** . For example, the following
        lines enable URLs with the HTTPS scheme:

        <key>LSApplicationQueriesSchemes</key>
            <array>
        <string>https</string>
            </array>

        **See also** **setUrlHandler** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QWizard(QDialog):
    """
    https://doc.qt.io/qt-6/qwizard.html

    **Detailed Description**

    A wizard (also called an assistant on macOS) is a special type of input
    dialog that consists of a sequence of pages. A wizard's purpose is to guide
    the user through a process step by step. Wizards are useful for complex or
    infrequent tasks that users may find difficult to learn.

    QWizard inherits **QDialog**  and represents a wizard. Each page is a
    **QWizardPage**  (a **QWidget**  subclass). To create your own wizards, you
    can use these classes directly, or you can subclass them for more control.

    Topics:

    **A Trivial Example**

    The following example illustrates how to create wizard pages and add them to
    a wizard. For more advanced examples, see **Class Wizard**  and **License
    Wizard** .

    **QWizardPage**  *createIntroPage()
        {
            **QWizardPage**  *page =
    new **QWizardPage** ;
            page->setTitle("Introduction");
    **QLabel**  *label = new **QLabel** ("This wizard will help you register
    your copy "
                                       "of Super Product Two.");
    label->setWordWrap(true);

            **QVBoxLayout**  *layout = new
    **QVBoxLayout** ;
            layout->addWidget(label);
    page->setLayout(layout);

            return page;
        }
    **QWizardPage**  *createRegistrationPage()
        {
            ...
        }
    **QWizardPage**  *createConclusionPage()
        {
            ...
        }
    int main(int argc, char *argv[])
        {
            **QApplication**  app(argc,
    argv);

        #ifndef QT_NO_TRANSLATION
            **QString**
    translatorFileName = QLatin1String("qtbase_");
            translatorFileName +=
    **QLocale** ::system().name();
            **QTranslator**  *translator = new
    **QTranslator** (&app);
            if (translator->load(translatorFileName,
    **QLibraryInfo** ::path(**QLibraryInfo** ::TranslationsPath)))
    app.installTranslator(translator);
        #endif

            **QWizard**
    wizard;
            wizard.addPage(createIntroPage());
    wizard.addPage(createRegistrationPage());
    wizard.addPage(createConclusionPage());
    wizard.setWindowTitle("Trivial Wizard");
            wizard.show();
    return app.exec();
        }

    **Wizard Look and Feel**

    QWizard supports four wizard looks:

    * **ClassicStyle**
      * **ModernStyle**
      * **MacStyle**
      * **AeroStyle**

    You can explicitly set the look to use using **setWizardStyle** () (e.g., if
    you want the same look on all platforms).

    **ClassicStyle** **ModernStyle** **MacStyle** **AeroStyle**
    ![](images/qtwizard-classic1.png)![](images/qtwizard-
    modern1.png)![](images/qtwizard-mac1.png)![](images/qtwizard-aero1.png)
    ![](images/qtwizard-classic2.png)![](images/qtwizard-
    modern2.png)![](images/qtwizard-mac2.png)![](images/qtwizard-aero2.png)

    Note: **AeroStyle**  has effect only on a Windows Vista system with alpha
    compositing enabled. **ModernStyle**  is used as a fallback when this
    condition is not met.

    In addition to the wizard style, there are several options that control the
    look and feel of the wizard. These can be set using **setOption** () or
    **setOptions** (). For example, **HaveHelpButton**  makes QWizard show a
    **Help** button along with the other wizard buttons.

    You can even change the order of the wizard buttons to any arbitrary order
    using **setButtonLayout** (), and you can add up to three custom buttons
    (e.g., a **Print** button) to the button row. This is achieved by calling
    **setButton** () or **setButtonText** () with **CustomButton1** ,
    **CustomButton2** , or **CustomButton3**  to set up the button, and by
    enabling the **HaveCustomButton1** , **HaveCustomButton2** , or
    **HaveCustomButton3**  options. Whenever the user clicks a custom button,
    **customButtonClicked** () is emitted. For example:

    wizard()->setButtonText(**QWizard** ::CustomButton1, tr("&Print"));
    wizard()->setOption(**QWizard** ::HaveCustomButton1, true);
    connect(wizard(), &**QWizard** ::customButtonClicked,
    this, &ConclusionPage::printButtonClicked);

    **Elements of a Wizard Page**

    Wizards consist of a sequence of **QWizardPage** s. At any time, only one
    page is shown. A page has the following attributes:

    * A **title** .
      * A **subTitle** .
      * A set of pixmaps, which may or may
    not be honored, depending on the wizard's style:
        * **WatermarkPixmap**
    (used by **ClassicStyle**  and **ModernStyle** )
        * **BannerPixmap**
    (used by **ModernStyle** )
        * **LogoPixmap**  (used by **ClassicStyle**
    and **ModernStyle** )
        * **BackgroundPixmap**  (used by **MacStyle** )

    The diagram belows shows how QWizard renders these attributes, assuming they
    are all present and **ModernStyle**  is used:

    ![](images/qtwizard-nonmacpage.png)

    When a **subTitle**  is set, QWizard displays it in a header, in which case
    it also uses the **BannerPixmap**  and the **LogoPixmap**  to decorate the
    header. The **WatermarkPixmap**  is displayed on the left side, below the
    header. At the bottom, there is a row of buttons allowing the user to
    navigate through the pages.

    The page itself (the **QWizardPage**  widget) occupies the area between the
    header, the watermark, and the button row. Typically, the page is a
    **QWizardPage**  on which a **QGridLayout**  is installed, with standard
    child widgets (**QLabel** s, **QLineEdit** s, etc.).

    If the wizard's style is **MacStyle** , the page looks radically different:

    ![](images/qtwizard-macpage.png)

    The watermark, banner, and logo pixmaps are ignored by the **MacStyle** . If
    the **BackgroundPixmap**  is set, it is used as the background for the
    wizard; otherwise, a default "assistant" image is used.

    The title and subtitle are set by calling **QWizardPage::setTitle** () and
    **QWizardPage::setSubTitle** () on the individual pages. They may be plain
    text or HTML (see **titleFormat**  and **subTitleFormat** ). The pixmaps can
    be set globally for the entire wizard using **setPixmap** (), or on a per-
    page basis using **QWizardPage::setPixmap** ().

    **Registering and Using Fields**

    In many wizards, the contents of a page may affect the default values of the
    fields of a later page. To make it easy to communicate between pages,
    QWizard supports a "field" mechanism that allows you to register a field
    (e.g., a **QLineEdit** ) on a page and to access its value from any page. It
    is also possible to specify mandatory fields (i.e., fields that must be
    filled before the user can advance to the next page).

    To register a field, call **QWizardPage::registerField** () field. For
    example:

    ClassInfoPage::ClassInfoPage(**QWidget**  *parent)
            : **QWizardPage**
    (parent)
        {
            ...
            classNameLabel = new **QLabel**
    (tr("&Class name:"));
            classNameLineEdit = new **QLineEdit** ;
    classNameLabel->setBuddy(classNameLineEdit);

            baseClassLabel =
    new **QLabel** (tr("B&ase class:"));
            baseClassLineEdit = new
    **QLineEdit** ;
            baseClassLabel->setBuddy(baseClassLineEdit);
    qobjectMacroCheckBox = new **QCheckBox** (tr("Generate Q_OBJECT &macro"));
    registerField("className*", classNameLineEdit);
    registerField("baseClass", baseClassLineEdit);
    registerField("qobjectMacro", qobjectMacroCheckBox);
            ...
        }

    The above code registers three fields, `className`, `baseClass`, and
    `qobjectMacro`, which are associated with three child widgets. The asterisk
    (`*`) next to `className` denotes a mandatory field.

    The fields of any page are accessible from any other page. For example:

    void OutputFilesPage::initializePage()
        {
            **QString**  className
    = field("className").toString();
    headerLineEdit->setText(className.toLower() + ".h");
    implementationLineEdit->setText(className.toLower() + ".cpp");
    outputDirLineEdit->setText(**QDir** ::toNativeSeparators(**QDir**
    ::tempPath()));
        }

    Here, we call **QWizardPage::field** () to access the contents of the
    `className` field (which was defined in the `ClassInfoPage`) and use it to
    initialize the `OutputFilePage`. The field's contents is returned as a
    **QVariant** .

    When we create a field using **QWizardPage::registerField** (), we pass a
    unique field name and a widget. We can also provide a Qt property name and a
    "changed" signal (a signal that is emitted when the property changes) as
    third and fourth arguments; however, this is not necessary for the most
    common Qt widgets, such as **QLineEdit** , **QCheckBox** , and **QComboBox**
    , because QWizard knows which properties to look for.

    If an asterisk (`*`) is appended to the name when the property is
    registered, the field is a **mandatory field**. When a page has mandatory
    fields, the **Next** and/or **Finish** buttons are enabled only when all
    mandatory fields are filled.

    To consider a field "filled", QWizard simply checks that the field's current
    value doesn't equal the original value (the value it had when
    **initializePage** () was called). For **QLineEdit**  and
    **QAbstractSpinBox**  subclasses, QWizard also checks that
    **hasAcceptableInput** () returns true, to honor any validator or mask.

    QWizard's mandatory field mechanism is provided for convenience. A more
    powerful (but also more cumbersome) alternative is to reimplement
    **QWizardPage::isComplete** () and to emit the
    **QWizardPage::completeChanged** () signal whenever the page becomes
    complete or incomplete.

    The enabled/disabled state of the **Next** and/or **Finish** buttons is one
    way to perform validation on the user input. Another way is to reimplement
    **validateCurrentPage** () (or **QWizardPage::validatePage** ()) to perform
    some last-minute validation (and show an error message if the user has
    entered incomplete or invalid information). If the function returns `true`,
    the next page is shown (or the wizard finishes); otherwise, the current page
    stays up.

    **Creating Linear Wizards**

    Most wizards have a linear structure, with page 1 followed by page 2 and so
    on until the last page. The **Class Wizard**  example is such a wizard. With
    QWizard, linear wizards are created by instantiating the **QWizardPage** s
    and inserting them using **addPage** (). By default, the pages are shown in
    the order in which they were added. For example:

    ClassWizard::ClassWizard(**QWidget**  *parent)
            : **QWizard**
    (parent)
        {
            addPage(new IntroPage);
            addPage(new
    ClassInfoPage);
            addPage(new CodeStylePage);
            addPage(new
    OutputFilesPage);
            addPage(new ConclusionPage);
            ...
        }

    When a page is about to be shown, QWizard calls **initializePage** () (which
    in turn calls **QWizardPage::initializePage** ()) to fill the page with
    default values. By default, this function does nothing, but it can be
    reimplemented to initialize the page's contents based on other pages' fields
    (see the **example above** ).

    If the user presses **Back** , **cleanupPage** () is called (which in turn
    calls **QWizardPage::cleanupPage** ()). The default implementation resets
    the page's fields to their original values (the values they had before
    **initializePage** () was called). If you want the **Back** button to be
    non-destructive and keep the values entered by the user, simply enable the
    **IndependentPages**  option.

    **Creating Non-Linear Wizards**

    Some wizards are more complex in that they allow different traversal paths
    based on the information provided by the user. The **License Wizard**
    example illustrates this. It provides five wizard pages; depending on which
    options are selected, the user can reach different pages.

    ![](images/licensewizard-flow.png)

    In complex wizards, pages are identified by IDs. These IDs are typically
    defined using an enum. For example:

    class LicenseWizard : public **QWizard**
        {
            ...
            enum {
    Page_Intro, Page_Evaluate, Page_Register, Page_Details,
    Page_Conclusion };
            ...
        };

    The pages are inserted using **setPage** (), which takes an ID and an
    instance of **QWizardPage**  (or of a subclass):

    LicenseWizard::LicenseWizard(**QWidget**  *parent)
            : **QWizard**
    (parent)
        {
            setPage(Page_Intro, new IntroPage);
    setPage(Page_Evaluate, new EvaluatePage);
            setPage(Page_Register, new
    RegisterPage);
            setPage(Page_Details, new DetailsPage);
    setPage(Page_Conclusion, new ConclusionPage);
            ...
        }

    By default, the pages are shown in increasing ID order. To provide a dynamic
    order that depends on the options chosen by the user, we must reimplement
    **QWizardPage::nextId** (). For example:

    int IntroPage::nextId() const
        {
            if
    (evaluateRadioButton->isChecked()) {
                return
    LicenseWizard::Page_Evaluate;
            } else {
                return
    LicenseWizard::Page_Register;
            }
        }

        int
    EvaluatePage::nextId() const
        {
            return
    LicenseWizard::Page_Conclusion;
        }

        int RegisterPage::nextId()
    const
        {
            if (upgradeKeyLineEdit->text().isEmpty()) {
    return LicenseWizard::Page_Details;
            } else {
                return
    LicenseWizard::Page_Conclusion;
            }
        }

        int
    DetailsPage::nextId() const
        {
            return
    LicenseWizard::Page_Conclusion;
        }

        int ConclusionPage::nextId()
    const
        {
            return -1;
        }

    It would also be possible to put all the logic in one place, in a
    **QWizard::nextId** () reimplementation. For example:

    int LicenseWizard::nextId() const
        {
            switch (currentId()) {
    case Page_Intro:
                if (field("intro.evaluate").toBool()) {
    return Page_Evaluate;
                } else {
                    return
    Page_Register;
                }
            case Page_Evaluate:
                return
    Page_Conclusion;
            case Page_Register:
                if
    (field("register.upgradeKey").toString().isEmpty()) {
                    return
    Page_Details;
                } else {
                    return Page_Conclusion;
    }
            case Page_Details:
                return Page_Conclusion;
    case Page_Conclusion:
            default:
                return -1;
            }
    }

    To start at another page than the page with the lowest ID, call
    **setStartId** ().

    To test whether a page has been visited or not, call **hasVisitedPage** ().
    For example:

    void ConclusionPage::initializePage()
        {
            **QString**
    licenseText;

            if
    (wizard()->hasVisitedPage(LicenseWizard::Page_Evaluate)) {
    licenseText = tr("<u>Evaluation License Agreement:</u> "
    "You can use this software for 30 days and make one "
    "backup, but you are not allowed to distribute it.");
            } else if
    (wizard()->hasVisitedPage(LicenseWizard::Page_Details)) {
    licenseText = tr("<u>First-Time License Agreement:</u> "
    "You can use this software subject to the license "
    "you will receive by email.");
            } else {
                licenseText =
    tr("<u>Upgrade License Agreement:</u> "
                                 "This
    software is licensed under the terms of your "
    "current license.");
            }
            bottomLabel->setText(licenseText);
    }

    **See also** **QWizardPage** , **Class Wizard Example** , and **License
    Wizard Example** .
    """

    class WizardOption(enum.Flag):
        IndependentPages: QWizard = ...
        IgnoreSubTitles: QWizard = ...
        ExtendedWatermarkPixmap: QWizard = ...
        NoDefaultButton: QWizard = ...
        NoBackButtonOnStartPage: QWizard = ...
        NoBackButtonOnLastPage: QWizard = ...
        DisabledBackButtonOnLastPage: QWizard = ...
        HaveNextButtonOnLastPage: QWizard = ...
        HaveFinishButtonOnEarlyPages: QWizard = ...
        NoCancelButton: QWizard = ...
        CancelButtonOnLeft: QWizard = ...
        HaveHelpButton: QWizard = ...
        HelpButtonOnRight: QWizard = ...
        HaveCustomButton1: QWizard = ...
        HaveCustomButton2: QWizard = ...
        HaveCustomButton3: QWizard = ...
        NoCancelButtonOnLastPage: QWizard = ...

    class WizardStyle(enum.Enum):
        ClassicStyle: QWizard = ...
        ModernStyle: QWizard = ...
        MacStyle: QWizard = ...
        AeroStyle: QWizard = ...

    class WizardPixmap(enum.Enum):
        WatermarkPixmap: QWizard = ...
        LogoPixmap: QWizard = ...
        BannerPixmap: QWizard = ...
        BackgroundPixmap: QWizard = ...

    class WizardButton(enum.Enum):
        BackButton: QWizard = ...
        NextButton: QWizard = ...
        CommitButton: QWizard = ...
        FinishButton: QWizard = ...
        CancelButton: QWizard = ...
        HelpButton: QWizard = ...
        CustomButton1: QWizard = ...
        CustomButton2: QWizard = ...
        CustomButton3: QWizard = ...
        Stretch: QWizard = ...

    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#QWizard

        **QWizard::QWizard(QWidget * parent = nullptr, Qt::WindowFlags flags =
        Qt::WindowFlags())**

        Constructs a wizard with the given **parent** and window **flags**.

        **See also** **parent** () and **windowFlags** ().
        """
        ...

    def sideWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qwizard.html#sideWidget

        **QWidget *QWizard::sideWidget() const**

        Returns the widget on the left side of the wizard or `nullptr`.

        By default, no side widget is present.

        **See also** **setSideWidget** ().
        """
        ...

    def setSideWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setSideWidget

        **void QWizard::setSideWidget(QWidget * widget )**

        Sets the given **widget** to be shown on the left side of the wizard.
        For styles which use the **WatermarkPixmap**  (**ClassicStyle**  and
        **ModernStyle** ) the side widget is displayed on top of the watermark,
        for other styles or when the watermark is not provided the side widget
        is displayed on the left side of the wizard.

        Passing `nullptr` shows no side widget.

        When the **widget** is not `nullptr` the wizard reparents it.

        Any previous side widget is hidden.

        You may call setSideWidget() with the same widget at different times.

        All widgets set here will be deleted by the wizard when it is destroyed
        unless you separately reparent the widget after setting some other side
        widget (or `nullptr`).

        By default, no side widget is present.

        **See also** **sideWidget** ().
        """
        ...

    def pageIds(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qwizard.html#pageIds

        **QList<int> QWizard::pageIds() const**

        Returns the list of page IDs.
        """
        ...

    def removePage(self, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#removePage

        **void QWizard::removePage(int id )**

        Removes the page with the given **id**. **cleanupPage** () will be
        called if necessary.

        **Note:** Removing a page may influence the value of the **startId**
        property.

        **See also** **addPage** (), **setPage** (), **pageRemoved** (), and
        **startId** ().
        """
        ...

    def cleanupPage(self, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#cleanupPage

        **[virtual protected] void QWizard::cleanupPage(int id )**

        This virtual function is called by **QWizard**  to clean up page **id**
        just before the user leaves it by clicking **Back** (unless the
        **QWizard::IndependentPages**  option is set).

        The default implementation calls **QWizardPage::cleanupPage** () on
        page( **id** ).

        **See also** **QWizardPage::cleanupPage** () and **initializePage** ().
        """
        ...

    def initializePage(self, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#initializePage

        **[virtual protected] void QWizard::initializePage(int id )**

        This virtual function is called by **QWizard**  to prepare page **id**
        just before it is shown either as a result of **QWizard::restart** ()
        being called, or as a result of the user clicking **Next**. (However, if
        the **QWizard::IndependentPages**  option is set, this function is only
        called the first time the page is shown.)

        By reimplementing this function, you can ensure that the page's fields
        are properly initialized based on fields from previous pages.

        The default implementation calls **QWizardPage::initializePage** () on
        page( **id** ).

        **See also** **QWizardPage::initializePage** () and **cleanupPage** ().
        """
        ...

    def done(self, result: int) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#done

        **[override virtual protected] void QWizard::done(int result )**

        Reimplements: **QDialog::done** (int r).
        """
        ...

    def paintEvent(self, event: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#paintEvent

        **[override virtual protected] void QWizard::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def resizeEvent(self, event: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#resizeEvent

        **[override virtual protected] void QWizard::resizeEvent(QResizeEvent *
        event )**

        Reimplements: **QDialog::resizeEvent** (QResizeEvent *).
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qwizard.html#event

        **[override virtual protected] bool QWizard::event(QEvent * event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def restart(self) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#restart

        **[slot] void QWizard::restart()**

        Restarts the wizard at the start page. This function is called
        automatically when the wizard is shown.

        **See also** **startId** ().
        """
        ...

    def next(self) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#next

        **[slot] void QWizard::next()**

        Advances to the next page.

        This is equivalent to pressing the **Next** or **Commit** button.

        **See also** **nextId** (), **back** (), **accept** (), **reject** (),
        and **restart** ().
        """
        ...

    def back(self) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#back

        **[slot] void QWizard::back()**

        Goes back to the previous page.

        This is equivalent to pressing the **Back** button.

        **See also** **next** (), **accept** (), **reject** (), and **restart**
        ().
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwizard.html#sizeHint

        **[override virtual] QSize QWizard::sizeHint() const**

        Reimplements: **QDialog::sizeHint() const** .
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setVisible

        **[override virtual] void QWizard::setVisible(bool visible )**

        Reimplements: **QDialog::setVisible** (bool visible).
        """
        ...

    def setDefaultProperty(
        self, className: str, property: str, changedSignal: PYQT_SIGNAL
    ) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setDefaultProperty

        **void QWizard::setDefaultProperty(const char * className , const char *
        property , const char * changedSignal )**

        Sets the default property for **className** to be **property** , and the
        associated change signal to be **changedSignal**.

        The default property is used when an instance of **className** (or of
        one of its subclasses) is passed to **QWizardPage::registerField** ()
        and no property is specified.

        **QWizard**  knows the most common Qt widgets. For these (or their
        subclasses), you don't need to specify a **property** or a
        **changedSignal**. The table below lists these widgets:

        WidgetPropertyChange Notification Signal
        **QAbstractButton** bool
        **checked** **toggled** ()
        **QAbstractSlider** int **value**
        **valueChanged** ()
        **QComboBox** int **currentIndex**
        **currentIndexChanged** ()
        **QDateTimeEdit** **QDateTime**
        **dateTime** **dateTimeChanged** ()
        **QLineEdit** **QString**
        **text** **textChanged** ()
        **QListWidget** int **currentRow**
        **currentRowChanged** ()
        **QSpinBox** int **value** **valueChanged**
        ()

        **See also** **QWizardPage::registerField** ().
        """
        ...

    def pixmap(self, which: "QWizard.WizardPixmap") -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qwizard.html#pixmap

        **QPixmap QWizard::pixmap(QWizard::WizardPixmap which ) const**

        Returns the pixmap set for role **which**.

        By default, the only pixmap that is set is the **BackgroundPixmap**  on
        macOS version 10.13 and earlier.

        **See also** **setPixmap** (), **QWizardPage::pixmap** (), and
        **Elements of a Wizard Page** .
        """
        ...

    def setPixmap(self, which: "QWizard.WizardPixmap", pixmap: QtGui.QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setPixmap

        **void QWizard::setPixmap(QWizard::WizardPixmap which , const QPixmap &
        pixmap )**

        Sets the pixmap for role **which** to **pixmap**.

        The pixmaps are used by **QWizard**  when displaying a page. Which
        pixmaps are actually used depend on the **wizard style** .

        Pixmaps can also be set for a specific page using
        **QWizardPage::setPixmap** ().

        **See also** **pixmap** (), **QWizardPage::setPixmap** (), and
        **Elements of a Wizard Page** .
        """
        ...

    def subTitleFormat(self) -> QtCore.Qt.TextFormat:
        """
        https://doc.qt.io/qt-6/qwizard.html#subTitleFormat-prop

        **subTitleFormat : Qt::TextFormat**

        This property holds the text format used by page subtitles

        The default format is **Qt::AutoText** .

        **Access functions:**

        Qt::TextFormat **subTitleFormat** () const
        void **setSubTitleFormat**
        (Qt::TextFormat **format** )

        **See also** **QWizardPage::title**  and **titleFormat** .
        """
        ...

    def setSubTitleFormat(self, format: QtCore.Qt.TextFormat) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#subTitleFormat-prop

        **subTitleFormat : Qt::TextFormat**

        This property holds the text format used by page subtitles

        The default format is **Qt::AutoText** .

        **Access functions:**

        Qt::TextFormat **subTitleFormat** () const
        void **setSubTitleFormat**
        (Qt::TextFormat **format** )

        **See also** **QWizardPage::title**  and **titleFormat** .
        """
        ...

    def titleFormat(self) -> QtCore.Qt.TextFormat:
        """
        https://doc.qt.io/qt-6/qwizard.html#titleFormat-prop

        **titleFormat : Qt::TextFormat**

        This property holds the text format used by page titles

        The default format is **Qt::AutoText** .

        **Access functions:**

        Qt::TextFormat **titleFormat** () const
        void **setTitleFormat**
        (Qt::TextFormat **format** )

        **See also** **QWizardPage::title**  and **subTitleFormat** .
        """
        ...

    def setTitleFormat(self, format: QtCore.Qt.TextFormat) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#titleFormat-prop

        **titleFormat : Qt::TextFormat**

        This property holds the text format used by page titles

        The default format is **Qt::AutoText** .

        **Access functions:**

        Qt::TextFormat **titleFormat** () const
        void **setTitleFormat**
        (Qt::TextFormat **format** )

        **See also** **QWizardPage::title**  and **subTitleFormat** .
        """
        ...

    def button(self, which: "QWizard.WizardButton") -> QAbstractButton:
        """
        https://doc.qt.io/qt-6/qwizard.html#button

        **QAbstractButton *QWizard::button(QWizard::WizardButton which ) const**

        Returns the button corresponding to role **which**.

        **See also** **setButton** () and **setButtonText** ().
        """
        ...

    def setButton(self, which: "QWizard.WizardButton", button: QAbstractButton) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setButton

        **void QWizard::setButton(QWizard::WizardButton which , QAbstractButton
        * button )**

        Sets the button corresponding to role **which** to **button**.

        To add extra buttons to the wizard (e.g., a **Print** button), one way
        is to call setButton() with **CustomButton1**  to **CustomButton3** ,
        and make the buttons visible using the **HaveCustomButton1**  to
        **HaveCustomButton3**  options.

        **See also** **button** (), **setButtonText** (), **setButtonLayout**
        (), and **options** .
        """
        ...

    def setButtonLayout(self, layout: typing.Iterable["QWizard.WizardButton"]) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setButtonLayout

        **void QWizard::setButtonLayout(const QList<QWizard::WizardButton> &
        layout )**

        Sets the order in which buttons are displayed to **layout** , where
        **layout** is a list of **WizardButton** s.

        The default layout depends on the options (e.g., whether
        **HelpButtonOnRight** ) that are set. You can call this function if you
        need more control over the buttons' layout than what **options**
        already provides.

        You can specify horizontal stretches in the layout using **Stretch** .

        Example:

        MyWizard::MyWizard(**QWidget**  *parent)
                : **QWizard** (parent)
        {
                ...
                **QList** <**QWizard** ::WizardButton> layout;
        layout << **QWizard** ::Stretch << **QWizard** ::BackButton <<
        **QWizard** ::CancelButton
                       << **QWizard** ::NextButton <<
        **QWizard** ::FinishButton;
                setButtonLayout(layout);
                ...
        }

        **See also** **setButton** (), **setButtonText** (), and **setOptions**
        ().
        """
        ...

    def buttonText(self, which: "QWizard.WizardButton") -> str:
        """
        https://doc.qt.io/qt-6/qwizard.html#buttonText

        **QString QWizard::buttonText(QWizard::WizardButton which ) const**

        Returns the text on button **which**.

        If a text has ben set using **setButtonText** (), this text is returned.

        By default, the text on buttons depends on the **wizardStyle** . For
        example, on macOS, the **Next** button is called **Continue**.

        **See also** **button** (), **setButton** (), **setButtonText** (),
        **QWizardPage::buttonText** (), and **QWizardPage::setButtonText** ().
        """
        ...

    def setButtonText(self, which: "QWizard.WizardButton", text: str) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setButtonText

        **void QWizard::setButtonText(QWizard::WizardButton which , const
        QString & text )**

        Sets the text on button **which** to be **text**.

        By default, the text on buttons depends on the **wizardStyle** . For
        example, on macOS, the **Next** button is called **Continue**.

        To add extra buttons to the wizard (e.g., a **Print** button), one way
        is to call setButtonText() with **CustomButton1** , **CustomButton2** ,
        or **CustomButton3**  to set their text, and make the buttons visible
        using the **HaveCustomButton1** , **HaveCustomButton2** , and/or
        **HaveCustomButton3**  options.

        Button texts may also be set on a per-page basis using
        **QWizardPage::setButtonText** ().

        **See also** **buttonText** (), **setButton** (), **button** (),
        **setButtonLayout** (), **setOptions** (), and
        **QWizardPage::setButtonText** ().
        """
        ...

    def options(self) -> "QWizard.WizardOption":
        """
        https://doc.qt.io/qt-6/qwizard.html#options-prop

        **options : WizardOptions**

        This property holds the various options that affect the look and feel of
        the wizard

        By default, the following options are set (depending on the platform):

        * Windows: **HelpButtonOnRight** .
          * macOS: **NoDefaultButton**  and
        **NoCancelButton** .
          * X11 and QWS (Qt for Embedded Linux): none.

        **Access functions:**

        QWizard::WizardOptions **options** () const
        void **setOptions**
        (QWizard::WizardOptions **options** )

        **See also** **wizardStyle** .
        """
        ...

    def setOptions(self, options: "QWizard.WizardOption") -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#options-prop

        **options : WizardOptions**

        This property holds the various options that affect the look and feel of
        the wizard

        By default, the following options are set (depending on the platform):

        * Windows: **HelpButtonOnRight** .
          * macOS: **NoDefaultButton**  and
        **NoCancelButton** .
          * X11 and QWS (Qt for Embedded Linux): none.

        **Access functions:**

        QWizard::WizardOptions **options** () const
        void **setOptions**
        (QWizard::WizardOptions **options** )

        **See also** **wizardStyle** .
        """
        ...

    def testOption(self, option: "QWizard.WizardOption") -> bool:
        """
        https://doc.qt.io/qt-6/qwizard.html#testOption

        **bool QWizard::testOption(QWizard::WizardOption option ) const**

        Returns `true` if the given **option** is enabled; otherwise, returns
        false.

        **See also** **options** , **setOption** (), and **setWizardStyle** ().
        """
        ...

    def setOption(self, option: "QWizard.WizardOption", on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setOption

        **void QWizard::setOption(QWizard::WizardOption option , bool on =
        true)**

        Sets the given **option** to be enabled if **on** is true; otherwise,
        clears the given **option**.

        **See also** **options** , **testOption** (), and **setWizardStyle** ().
        """
        ...

    def wizardStyle(self) -> "QWizard.WizardStyle":
        """
        https://doc.qt.io/qt-6/qwizard.html#wizardStyle-prop

        **wizardStyle : WizardStyle**

        This property holds the look and feel of the wizard

        By default, **QWizard**  uses the **AeroStyle**  on a Windows Vista
        system with alpha compositing enabled, regardless of the current widget
        style. If this is not the case, the default wizard style depends on the
        current widget style as follows: **MacStyle**  is the default if the
        current widget style is QMacStyle, **ModernStyle**  is the default if
        the current widget style is QWindowsStyle, and **ClassicStyle**  is the
        default in all other cases.

        **Access functions:**

        QWizard::WizardStyle **wizardStyle** () const
        void **setWizardStyle**
        (QWizard::WizardStyle **style** )

        **See also** **Wizard Look and Feel**  and **options** .

        **Member Function Documentation**
        """
        ...

    def setWizardStyle(self, style: "QWizard.WizardStyle") -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#wizardStyle-prop

        **wizardStyle : WizardStyle**

        This property holds the look and feel of the wizard

        By default, **QWizard**  uses the **AeroStyle**  on a Windows Vista
        system with alpha compositing enabled, regardless of the current widget
        style. If this is not the case, the default wizard style depends on the
        current widget style as follows: **MacStyle**  is the default if the
        current widget style is QMacStyle, **ModernStyle**  is the default if
        the current widget style is QWindowsStyle, and **ClassicStyle**  is the
        default in all other cases.

        **Access functions:**

        QWizard::WizardStyle **wizardStyle** () const
        void **setWizardStyle**
        (QWizard::WizardStyle **style** )

        **See also** **Wizard Look and Feel**  and **options** .

        **Member Function Documentation**
        """
        ...

    def field(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qwizard.html#field

        **QVariant QWizard::field(const QString & name ) const**

        Returns the value of the field called **name**.

        This function can be used to access fields on any page of the wizard.

        **See also** **QWizardPage::registerField** (), **QWizardPage::field**
        (), and **setField** ().
        """
        ...

    def setField(self, name: str, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setField

        **void QWizard::setField(const QString & name , const QVariant & value
        )**

        Sets the value of the field called **name** to **value**.

        This function can be used to set fields on any page of the wizard.

        **See also** **QWizardPage::registerField** (),
        **QWizardPage::setField** (), and **field** ().
        """
        ...

    def nextId(self) -> int:
        """
        https://doc.qt.io/qt-6/qwizard.html#nextId

        **[virtual] int QWizard::nextId() const**

        This virtual function is called by **QWizard**  to find out which page
        to show when the user clicks the **Next** button.

        The return value is the ID of the next page, or -1 if no page follows.

        The default implementation calls **QWizardPage::nextId** () on the
        **currentPage** ().

        By reimplementing this function, you can specify a dynamic page order.

        **See also** **QWizardPage::nextId** () and **currentPage** ().
        """
        ...

    def validateCurrentPage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwizard.html#validateCurrentPage

        **[virtual] bool QWizard::validateCurrentPage()**

        This virtual function is called by **QWizard**  when the user clicks
        **Next** or **Finish** to perform some last-minute validation. If it
        returns `true`, the next page is shown (or the wizard finishes);
        otherwise, the current page stays up.

        The default implementation calls **QWizardPage::validatePage** () on the
        **currentPage** ().

        When possible, it is usually better style to disable the **Next** or
        **Finish** button (by specifying **mandatory fields**  or by
        reimplementing **QWizardPage::isComplete** ()) than to reimplement
        validateCurrentPage().

        **See also** **QWizardPage::validatePage** () and **currentPage** ().
        """
        ...

    def currentId(self) -> int:
        """
        https://doc.qt.io/qt-6/qwizard.html#currentId-prop

        **[read-only] currentId : const int**

        This property holds the ID of the current page

        This property cannot be set directly. To change the current page, call
        **next** (), **back** (), or **restart** ().

        By default, this property has a value of -1, indicating that no page is
        currently shown.

        **Access functions:**

        int **currentId** () const

        **Notifier signal:**

        void ****currentIdChanged** ** (int **id** )

        **See also** **currentPage** ().
        """
        ...

    def currentPage(self) -> "QWizardPage":
        """
        https://doc.qt.io/qt-6/qwizard.html#currentPage

        **QWizardPage *QWizard::currentPage() const**

        Returns a pointer to the current page, or `nullptr` if there is no
        current page (e.g., before the wizard is shown).

        This is equivalent to calling page(**currentId** ()).

        **See also** **page** (), **currentId** (), and **restart** ().
        """
        ...

    def startId(self) -> int:
        """
        https://doc.qt.io/qt-6/qwizard.html#startId-prop

        **startId : int**

        This property holds the ID of the first page

        If this property isn't explicitly set, this property defaults to the
        lowest page ID in this wizard, or -1 if no page has been inserted yet.

        **Access functions:**

        int **startId** () const
        void **setStartId** (int **id** )

        **See also** **restart** () and **nextId** ().
        """
        ...

    def setStartId(self, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#startId-prop

        **startId : int**

        This property holds the ID of the first page

        If this property isn't explicitly set, this property defaults to the
        lowest page ID in this wizard, or -1 if no page has been inserted yet.

        **Access functions:**

        int **startId** () const
        void **setStartId** (int **id** )

        **See also** **restart** () and **nextId** ().
        """
        ...

    def visitedIds(self) -> typing.List[int]:
        """
        https://doc.qt.io/qt-6/qwizard.html#visitedIds

        **[since 5.15] QList<int> QWizard::visitedIds() const**

        Returns the list of IDs of visited pages, in the order in which the
        pages were visited.

        This function was introduced in Qt 5.15.

        **See also** **hasVisitedPage** ().
        """
        ...

    def hasVisitedPage(self, id: int) -> bool:
        """
        https://doc.qt.io/qt-6/qwizard.html#hasVisitedPage

        **bool QWizard::hasVisitedPage(int id ) const**

        Returns `true` if the page history contains page **id** ; otherwise,
        returns `false`.

        Pressing **Back** marks the current page as "unvisited" again.

        **See also** **visitedIds** ().
        """
        ...

    def page(self, id: int) -> "QWizardPage":
        """
        https://doc.qt.io/qt-6/qwizard.html#page

        **QWizardPage *QWizard::page(int id ) const**

        Returns the page with the given **id** , or `nullptr` if there is no
        such page.

        **See also** **addPage** () and **setPage** ().
        """
        ...

    def setPage(self, id: int, page: "QWizardPage") -> None:
        """
        https://doc.qt.io/qt-6/qwizard.html#setPage

        **void QWizard::setPage(int id , QWizardPage * page )**

        Adds the given **page** to the wizard with the given **id**.

        **Note:** Adding a page may influence the value of the **startId**
        property in case it was not set explicitly.

        **See also** **addPage** (), **page** (), and **pageAdded** ().
        """
        ...

    def addPage(self, page: "QWizardPage") -> int:
        """
        https://doc.qt.io/qt-6/qwizard.html#addPage

        **int QWizard::addPage(QWizardPage * page )**

        Adds the given **page** to the wizard, and returns the page's ID.

        The ID is guaranteed to be larger than any other ID in the **QWizard**
        so far.

        **See also** **setPage** (), **page** (), and **pageAdded** ().
        """
        ...

    @property
    def currentIdChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwizard.html#currentIdChanged

        **[signal] void QWizard::currentIdChanged(int id )**

        This signal is emitted when the current page changes, with the new
        current **id**.

        **Note:** Notifier signal for property **currentId** .

        **See also** **currentId** () and **currentPage** ().
        """
        ...

    @property
    def customButtonClicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwizard.html#customButtonClicked

        **[signal] void QWizard::customButtonClicked(int which )**

        This signal is emitted when the user clicks a custom button. **which**
        can be **CustomButton1** , **CustomButton2** , or **CustomButton3** .

        By default, no custom button is shown. Call **setOption** () with
        **HaveCustomButton1** , **HaveCustomButton2** , or **HaveCustomButton3**
        to have one, and use **setButtonText** () or **setButton** () to
        configure it.

        **See also** **helpRequested** ().
        """
        ...

    @property
    def helpRequested(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwizard.html#helpRequested

        **[signal] void QWizard::helpRequested()**

        This signal is emitted when the user clicks the **Help** button.

        By default, no **Help** button is shown. Call **setOption**
        (**HaveHelpButton** , true) to have one.

        Example:

        LicenseWizard::LicenseWizard(**QWidget**  *parent)
                : **QWizard**
        (parent)
            {
                ...
                setOption(HaveHelpButton, true);
        connect(this, &**QWizard** ::helpRequested, this,
        &LicenseWizard::showHelp);
                ...
            }

            void
        LicenseWizard::showHelp()
            {
                static **QString**
        lastHelpMessage;

                **QString**  message;

                switch
        (currentId()) {
                case Page_Intro:
                    message = tr("The
        decision you make here will affect which page you "
        "get to see next.");
                    break;
                ...
                default:
        message = tr("This help is likely not to be of any help.");
                }
        **QMessageBox** ::information(this, tr("License Wizard Help"), message);
        }

        **See also** **customButtonClicked** ().
        """
        ...

    @property
    def pageAdded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwizard.html#pageAdded

        **[signal] void QWizard::pageAdded(int id )**

        This signal is emitted whenever a page is added to the wizard. The
        page's **id** is passed as parameter.

        **See also** **addPage** (), **setPage** (), and **startId** ().
        """
        ...

    @property
    def pageRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qwizard.html#pageRemoved

        **[signal] void QWizard::pageRemoved(int id )**

        This signal is emitted whenever a page is removed from the wizard. The
        page's **id** is passed as parameter.

        **See also** **removePage** () and **startId** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtSensors import *


class QLightSensor(QSensor):
    """
    https://doc.qt.io/qt-6/qlightsensor.html

    **Detailed Description**

    The only behavioural difference is that this class sets the type properly.

    This class also features a **reading** () function that returns a
    **QLightReading**  instead of a **QSensorReading** .

    For details about how the sensor works, see **QLightReading** .

    **See also** **QLightReading** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlightsensor.html#QLightSensor

        **QLightSensor::QLightSensor(QObject * parent = nullptr)**

        Construct the sensor as a child of **parent**.
        """
        ...

    def setFieldOfView(self, fieldOfView: float) -> None:
        """
        https://doc.qt.io/qt-6/qlightsensor.html#setFieldOfView

        **[since 5.1] void QLightSensor::setFieldOfView(qreal fieldOfView )**

        Sets the field of view to **fieldOfView**. This is to be called from the
        backend.

        This function was introduced in Qt 5.1.

        **See also** **fieldOfView** ().
        """
        ...

    def fieldOfView(self) -> float:
        """
        https://doc.qt.io/qt-6/qlightsensor.html#fieldOfView-prop

        **[read-only] fieldOfView : const qreal**

        This property holds a value indicating the field of view.

        This is an angle that represents the field of view of the sensor.

        Not all light sensor support retrieving their field of view. For sensors
        that don't support this property, the value will be 0. Whether the field
        of view is supported can be checked with **QSensor::isFeatureSupported**
        () and the **QSensor::FieldOfView**  flag.

        **Access functions:**

        qreal **fieldOfView** () const

        **Notifier signal:**

        void **fieldOfViewChanged** (qreal **fieldOfView** )

        **Member Function Documentation**
        """
        ...

    def reading(self) -> QLightReading:
        """
        https://doc.qt.io/qt-6/qlightsensor.html#reading

        **QLightReading *QLightSensor::reading() const**

        Returns the reading class for this sensor.

        **See also** **QSensor::reading** ().
        """
        ...

    @property
    def fieldOfViewChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtSql import *


class QSqlDriverCreatorBase(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qsqldrivercreatorbase.html

    **Detailed Description**

    Reimplement **createObject** () to return an instance of the specific
    **QSqlDriver**  subclass that you want to provide.

    See **QSqlDatabase::registerSqlDriver** () for details.

    **See also** **QSqlDriverCreator** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QSqlDriverCreatorBase") -> None:
        ...

    def createObject(self) -> "QSqlDriver":
        """
        https://doc.qt.io/qt-6/qsqldrivercreatorbase.html#createObject

        **[pure virtual] QSqlDriver *QSqlDriverCreatorBase::createObject()
        const**

        Reimplement this function to returns a new instance of a **QSqlDriver**
        subclass.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QPropertyAnimation(QVariantAnimation):
    """
    https://doc.qt.io/qt-6/qpropertyanimation.html

    **Detailed Description**

    QPropertyAnimation interpolates over **Qt properties** . As property values
    are stored in **QVariant** s, the class inherits **QVariantAnimation** , and
    supports animation of the same **meta types**  as its super class.

    A class declaring properties must be a **QObject** . To make it possible to
    animate a property, it must provide a setter (so that QPropertyAnimation can
    set the property's value). Note that this makes it possible to animate many
    of Qt's widgets. Let's look at an example:

    **QPropertyAnimation**  *animation = new **QPropertyAnimation** (myWidget,
    "geometry");
            animation->setDuration(10000);
    animation->setStartValue(**QRect** (0, 0, 100, 30));
    animation->setEndValue(**QRect** (250, 250, 100, 30));
    animation->start();

    The property name and the **QObject**  instance of which property should be
    animated are passed to the constructor. You can then specify the start and
    end value of the property. The procedure is equal for properties in classes
    you have implemented yourself--just check with **QVariantAnimation**  that
    your **QVariant**  type is supported.

    The **QVariantAnimation**  class description explains how to set up the
    animation in detail. Note, however, that if a start value is not set, the
    property will start at the value it had when the QPropertyAnimation instance
    was created.

    QPropertyAnimation works like a charm on its own. For complex animations
    that, for instance, contain several objects, **QAnimationGroup**  is
    provided. An animation group is an animation that can contain other
    animations, and that can manage when its animations are played. Look at
    **QParallelAnimationGroup**  for an example.

    **See also** **QVariantAnimation** , **QAnimationGroup** , and **The
    Animation Framework** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#QPropertyAnimation

        **QPropertyAnimation::QPropertyAnimation(QObject * parent = nullptr)**

        Construct a QPropertyAnimation object. **parent** is passed to
        **QObject** 's constructor.
        """
        ...

    @typing.overload
    def __init__(
        self,
        target: QObject,
        propertyName: QByteArray,
        parent: typing.Optional[QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#QPropertyAnimation-1

        **QPropertyAnimation::QPropertyAnimation(QObject * target , const
        QByteArray & propertyName , QObject * parent = nullptr)**

        Construct a QPropertyAnimation object. **parent** is passed to
        **QObject** 's constructor. The animation changes the property
        **propertyName** on **target**. The default duration is 250ms.

        **See also** **targetObject**  and **propertyName** .
        """
        ...

    def updateState(
        self, newState: QAbstractAnimation.State, oldState: QAbstractAnimation.State
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#updateState

        **[override virtual protected] void
        QPropertyAnimation::updateState(QAbstractAnimation::State newState ,
        QAbstractAnimation::State oldState )**

        Reimplements: **QVariantAnimation::updateState**
        (QAbstractAnimation::State newState, QAbstractAnimation::State
        oldState).

        If the startValue is not defined when the state of the animation changes
        from Stopped to Running, the current property value is used as the
        initial value for the animation.
        """
        ...

    def updateCurrentValue(self, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#updateCurrentValue

        **[override virtual protected] void
        QPropertyAnimation::updateCurrentValue(const QVariant & value )**

        Reimplements: **QVariantAnimation::updateCurrentValue** (const QVariant
        &value).

        This virtual function is called by **QVariantAnimation**  whenever the
        current value changes. **value** is the new, updated value. It updates
        the current value of the property on the target object.

        **See also** **currentValue**  and **currentTime** .
        """
        ...

    def event(self, event: QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#event

        **[override virtual protected] bool QPropertyAnimation::event(QEvent *
        event )**

        Reimplements: **QVariantAnimation::event** (QEvent *event).
        """
        ...

    def setPropertyName(self, propertyName: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#propertyName-prop

        **[bindable] propertyName : QByteArray**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the target property name for this animation

        This property defines the target property name for this animation. The
        property name is required for the animation to operate.
        """
        ...

    def propertyName(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#propertyName-prop

        **[bindable] propertyName : QByteArray**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the target property name for this animation

        This property defines the target property name for this animation. The
        property name is required for the animation to operate.
        """
        ...

    def setTargetObject(self, target: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#targetObject-prop

        **[bindable] targetObject : QObject***

        **Note:** This property supports **QProperty**  bindings.

        This property holds the target **QObject**  for this animation.

        This property defines the target **QObject**  for this animation.

        **Member Function Documentation**
        """
        ...

    def targetObject(self) -> QObject:
        """
        https://doc.qt.io/qt-6/qpropertyanimation.html#targetObject-prop

        **[bindable] targetObject : QObject***

        **Note:** This property supports **QProperty**  bindings.

        This property holds the target **QObject**  for this animation.

        This property defines the target **QObject**  for this animation.

        **Member Function Documentation**
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsOpacityEffect(QGraphicsEffect):
    """
    https://doc.qt.io/qt-6/qgraphicsopacityeffect.html

    **Detailed Description**

    An opacity effect renders the source with an opacity. This effect is useful
    for making the source semi-transparent, similar to a fade-in/fade-out
    sequence. The opacity can be modified using the **setOpacity** () function.

    By default, the opacity is 0.7.

    ![](images/graphicseffect-opacity.png)

    **See also** **QGraphicsDropShadowEffect** , **QGraphicsBlurEffect** , and
    **QGraphicsColorizeEffect** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsopacityeffect.html#QGraphicsOpacityEffec
        t

        **QGraphicsOpacityEffect::QGraphicsOpacityEffect(QObject * parent =
        nullptr)**

        Constructs a new QGraphicsOpacityEffect instance. The **parent**
        parameter is passed to **QGraphicsEffect** 's constructor.
        """
        ...

    def draw(self, painter: QtGui.QPainter) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsopacityeffect.html#draw

        **[override virtual protected] void
        QGraphicsOpacityEffect::draw(QPainter * painter )**

        Reimplements: **QGraphicsEffect::draw** (QPainter *painter).
        """
        ...

    def setOpacityMask(
        self,
        mask: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsopacityeffect.html#opacityMask-prop

        **opacityMask : QBrush**

        This property holds the opacity mask of the effect.

        An opacity mask allows you apply opacity to portions of an element.

        For example:

        ...
            **QLinearGradient**  alphaGradient(rect.topLeft(),
        rect.bottomLeft());
            alphaGradient.setColorAt(0.0, Qt::transparent);
        alphaGradient.setColorAt(0.5, Qt::black);
        alphaGradient.setColorAt(1.0, Qt::transparent);
        **QGraphicsOpacityEffect**  *effect = new **QGraphicsOpacityEffect** ;
        effect->setOpacityMask(alphaGradient);
            ...

        There is no opacity mask by default.

        **Access functions:**

        QBrush **opacityMask** () const
        void **setOpacityMask** (const QBrush
        & **mask** )

        **Notifier signal:**

        void ****opacityMaskChanged** ** (const QBrush & **mask** )

        **See also** **setOpacity** ().

        **Member Function Documentation**
        """
        ...

    def setOpacity(self, opacity: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsopacityeffect.html#opacity-prop

        **opacity : qreal**

        This property holds the opacity of the effect.

        The value should be in the range of 0.0 to 1.0, where 0.0 is fully
        transparent and 1.0 is fully opaque.

        By default, the opacity is 0.7.

        **Access functions:**

        qreal **opacity** () const
        void **setOpacity** (qreal **opacity** )

        **Notifier signal:**

        void ****opacityChanged** ** (qreal **opacity** )

        **See also** **setOpacityMask** ().
        """
        ...

    def opacityMask(self) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qgraphicsopacityeffect.html#opacityMask-prop

        **opacityMask : QBrush**

        This property holds the opacity mask of the effect.

        An opacity mask allows you apply opacity to portions of an element.

        For example:

        ...
            **QLinearGradient**  alphaGradient(rect.topLeft(),
        rect.bottomLeft());
            alphaGradient.setColorAt(0.0, Qt::transparent);
        alphaGradient.setColorAt(0.5, Qt::black);
        alphaGradient.setColorAt(1.0, Qt::transparent);
        **QGraphicsOpacityEffect**  *effect = new **QGraphicsOpacityEffect** ;
        effect->setOpacityMask(alphaGradient);
            ...

        There is no opacity mask by default.

        **Access functions:**

        QBrush **opacityMask** () const
        void **setOpacityMask** (const QBrush
        & **mask** )

        **Notifier signal:**

        void ****opacityMaskChanged** ** (const QBrush & **mask** )

        **See also** **setOpacity** ().

        **Member Function Documentation**
        """
        ...

    def opacity(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsopacityeffect.html#opacity-prop

        **opacity : qreal**

        This property holds the opacity of the effect.

        The value should be in the range of 0.0 to 1.0, where 0.0 is fully
        transparent and 1.0 is fully opaque.

        By default, the opacity is 0.7.

        **Access functions:**

        qreal **opacity** () const
        void **setOpacity** (qreal **opacity** )

        **Notifier signal:**

        void ****opacityChanged** ** (qreal **opacity** )

        **See also** **setOpacityMask** ().
        """
        ...

    @property
    def opacityChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsopacityeffect.html#opacityChanged

        **[signal] void QGraphicsOpacityEffect::opacityChanged(qreal opacity )**

        This signal is emitted whenever the effect's opacity changes. The
        **opacity** parameter holds the effect's new opacity.

        **Note:** Notifier signal for property **opacity** .
        """
        ...

    @property
    def opacityMaskChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicsopacityeffect.html#opacityMaskChanged

        **[signal] void QGraphicsOpacityEffect::opacityMaskChanged(const QBrush
        & mask )**

        This signal is emitted whenever the effect's opacity mask changes. The
        **mask** parameter holds the effect's new opacity mask.

        **Note:** Notifier signal for property **opacityMask** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QFrame(QWidget):
    """
    https://doc.qt.io/qt-6/qframe.html

    **Detailed Description**

    **QMenu**  uses this to "raise" the menu above the surrounding screen.
    **QProgressBar**  has a "sunken" look. **QLabel**  has a flat look. The
    frames of widgets like these can be changed.

    **QLabel**  label(...);
        label.setFrameStyle(**QFrame** ::Panel |
    **QFrame** ::Raised);
        label.setLineWidth(2);

        **QProgressBar**
    pbar(...);
        label.setFrameStyle(**QFrame** ::NoFrame);

    The QFrame class can also be used directly for creating simple placeholder
    frames without any contents.

    The frame style is specified by a **frame shape**  and a **shadow style**
    that is used to visually separate the frame from surrounding widgets. These
    properties can be set together using the **setFrameStyle** () function and
    read with **frameStyle** ().

    The frame shapes are **NoFrame** , **Box** , **Panel** , **StyledPanel** ,
    **HLine**  and **VLine** ; the shadow styles are **Plain** , **Raised**  and
    **Sunken** .

    A frame widget has three attributes that describe the thickness of the
    border: **lineWidth** , **midLineWidth** , and **frameWidth** .

    * The line width is the width of the frame border. It can be modified to
    customize the frame's appearance.
      * The mid-line width specifies the width
    of an extra line in the middle of the frame, which uses a third color to
    obtain a special 3D effect. Notice that a mid-line is only drawn for **Box**
    , **HLine**  and **VLine**  frames that are raised or sunken.
      * The frame
    width is determined by the frame style, and the **frameWidth** () function
    is used to obtain the value defined for the style used.

    The margin between the frame and the contents of the frame can be customized
    with the **QWidget::setContentsMargins** () function.

    This table shows some of the combinations of styles and line widths:

    ![Table of frame styles](images/frames.png)
    """

    class StyleMask(enum.Enum):
        Shadow_Mask: QFrame = ...
        Shape_Mask: QFrame = ...

    class Shape(enum.IntEnum):
        NoFrame: QFrame = ...
        Box: QFrame = ...
        Panel: QFrame = ...
        WinPanel: QFrame = ...
        HLine: QFrame = ...
        VLine: QFrame = ...
        StyledPanel: QFrame = ...

    class Shadow(enum.IntEnum):
        Plain: QFrame = ...
        Raised: QFrame = ...
        Sunken: QFrame = ...

    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#QFrame

        **QFrame::QFrame(QWidget * parent = nullptr, Qt::WindowFlags f =
        Qt::WindowFlags())**

        Constructs a frame widget with frame style **NoFrame**  and a 1-pixel
        frame width.

        The **parent** and **f** arguments are passed to the **QWidget**
        constructor.
        """
        ...

    def initStyleOption(self, option: "QStyleOptionFrame") -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#initStyleOption

        **[virtual protected, since 5.5] void
        QFrame::initStyleOption(QStyleOptionFrame * option ) const**

        Initializes **option** with the values from this **QFrame** . This
        method is useful for subclasses when they need a **QStyleOptionFrame**
        but don't want to fill in all the information themselves.

        This function was introduced in Qt 5.5.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def drawFrame(self, a0: QtGui.QPainter) -> None:
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#changeEvent

        **[override virtual protected] void QFrame::changeEvent(QEvent * ev )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#paintEvent

        **[override virtual protected] void QFrame::paintEvent(QPaintEvent *)**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qframe.html#event

        **[override virtual protected] bool QFrame::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def setFrameRect(self, a0: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#frameRect-prop

        **frameRect : QRect**

        This property holds the frame's rectangle

        The frame's rectangle is the rectangle the frame is drawn in. By
        default, this is the entire widget. Setting the rectangle does does
        **not** cause a widget update. The frame rectangle is automatically
        adjusted when the widget changes size.

        If you set the rectangle to a null rectangle (for example, **QRect** (0,
        0, 0, 0)), then the resulting frame rectangle is equivalent to the
        **widget rectangle** .

        **Access functions:**

        QRect **frameRect** () const
        void **setFrameRect** (const QRect &)
        """
        ...

    def frameRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qframe.html#frameRect-prop

        **frameRect : QRect**

        This property holds the frame's rectangle

        The frame's rectangle is the rectangle the frame is drawn in. By
        default, this is the entire widget. Setting the rectangle does does
        **not** cause a widget update. The frame rectangle is automatically
        adjusted when the widget changes size.

        If you set the rectangle to a null rectangle (for example, **QRect** (0,
        0, 0, 0)), then the resulting frame rectangle is equivalent to the
        **widget rectangle** .

        **Access functions:**

        QRect **frameRect** () const
        void **setFrameRect** (const QRect &)
        """
        ...

    def setMidLineWidth(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#midLineWidth-prop

        **midLineWidth : int**

        This property holds the width of the mid-line

        The default value is 0.

        **Access functions:**

        int **midLineWidth** () const
        void **setMidLineWidth** (int)

        **See also** **lineWidth**  and **frameWidth** .

        **Member Function Documentation**
        """
        ...

    def midLineWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qframe.html#midLineWidth-prop

        **midLineWidth : int**

        This property holds the width of the mid-line

        The default value is 0.

        **Access functions:**

        int **midLineWidth** () const
        void **setMidLineWidth** (int)

        **See also** **lineWidth**  and **frameWidth** .

        **Member Function Documentation**
        """
        ...

    def setLineWidth(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#lineWidth-prop

        **lineWidth : int**

        This property holds the line width

        Note that the **total** line width for frames used as separators
        (**HLine**  and **VLine** ) is specified by **frameWidth** .

        The default value is 1.

        **Access functions:**

        int **lineWidth** () const
        void **setLineWidth** (int)

        **See also** **midLineWidth**  and **frameWidth** .
        """
        ...

    def lineWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qframe.html#lineWidth-prop

        **lineWidth : int**

        This property holds the line width

        Note that the **total** line width for frames used as separators
        (**HLine**  and **VLine** ) is specified by **frameWidth** .

        The default value is 1.

        **Access functions:**

        int **lineWidth** () const
        void **setLineWidth** (int)

        **See also** **midLineWidth**  and **frameWidth** .
        """
        ...

    def setFrameShadow(self, a0: "QFrame.Shadow") -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#frameShadow-prop

        **frameShadow : Shadow**

        This property holds the frame shadow value from the frame style

        **Access functions:**

        QFrame::Shadow **frameShadow** () const
        void **setFrameShadow**
        (QFrame::Shadow)

        **See also** **frameStyle** () and **frameShape** ().
        """
        ...

    def frameShadow(self) -> "QFrame.Shadow":
        """
        https://doc.qt.io/qt-6/qframe.html#frameShadow-prop

        **frameShadow : Shadow**

        This property holds the frame shadow value from the frame style

        **Access functions:**

        QFrame::Shadow **frameShadow** () const
        void **setFrameShadow**
        (QFrame::Shadow)

        **See also** **frameStyle** () and **frameShape** ().
        """
        ...

    def setFrameShape(self, a0: "QFrame.Shape") -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#frameShape-prop

        **frameShape : Shape**

        This property holds the frame shape value from the frame style

        **Access functions:**

        QFrame::Shape **frameShape** () const
        void **setFrameShape**
        (QFrame::Shape)

        **See also** **frameStyle** () and **frameShadow** ().
        """
        ...

    def frameShape(self) -> "QFrame.Shape":
        """
        https://doc.qt.io/qt-6/qframe.html#frameShape-prop

        **frameShape : Shape**

        This property holds the frame shape value from the frame style

        **Access functions:**

        QFrame::Shape **frameShape** () const
        void **setFrameShape**
        (QFrame::Shape)

        **See also** **frameStyle** () and **frameShadow** ().
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qframe.html#sizeHint

        **[override virtual] QSize QFrame::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    def frameWidth(self) -> int:
        """
        https://doc.qt.io/qt-6/qframe.html#frameWidth-prop

        **[read-only] frameWidth : const int**

        This property holds the width of the frame that is drawn.

        Note that the frame width depends on the **frame style** , not only the
        line width and the mid-line width. For example, the style specified by
        **NoFrame**  always has a frame width of 0, whereas the style **Panel**
        has a frame width equivalent to the line width.

        **Access functions:**

        int **frameWidth** () const

        **See also** **lineWidth** (), **midLineWidth** (), and **frameStyle**
        ().
        """
        ...

    def setFrameStyle(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qframe.html#setFrameStyle

        **void QFrame::setFrameStyle(int style )**

        Sets the frame style to **style**.

        The **style** is the bitwise OR between a frame shape and a frame shadow
        style. See the picture of the frames in the main class documentation.

        The frame shapes are given in **QFrame::Shape**  and the shadow styles
        in **QFrame::Shadow** .

        If a mid-line width greater than 0 is specified, an additional line is
        drawn for **Raised**  or **Sunken**  **Box** , **HLine** , and **VLine**
        frames. The mid-color of the current color group is used for drawing
        middle lines.

        **See also** **frameStyle** ().
        """
        ...

    def frameStyle(self) -> int:
        """
        https://doc.qt.io/qt-6/qframe.html#frameStyle

        **int QFrame::frameStyle() const**

        Returns the frame style.

        The default value is **QFrame::Plain** .

        **See also** **setFrameStyle** (), **frameShape** (), and
        **frameShadow** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QProcessEnvironment(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qprocessenvironment.html

    **Detailed Description**

    A process's environment is composed of a set of key=value pairs known as
    environment variables. The QProcessEnvironment class wraps that concept and
    allows easy manipulation of those variables. It's meant to be used along
    with **QProcess** , to set the environment for child processes. It cannot be
    used to change the current process's environment.

    The environment of the calling process can be obtained using
    **QProcessEnvironment::systemEnvironment** ().

    On Unix systems, the variable names are case-sensitive. Note that the Unix
    environment allows both variable names and contents to contain arbitrary
    binary data (except for the NUL character). QProcessEnvironment will
    preserve such variables, but does not support manipulating variables whose
    names or values cannot be encoded by the current locale settings (see
    **QString::toLocal8Bit** ).

    On Windows, the variable names are case-insensitive, but case-preserving.
    QProcessEnvironment behaves accordingly.

    **See also** **QProcess** , **QProcess::systemEnvironment** (), and
    **QProcess::setProcessEnvironment** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#QProcessEnvironment

        **QProcessEnvironment::QProcessEnvironment()**

        Creates a new QProcessEnvironment object. This constructor creates an
        empty environment. If set on a **QProcess** , this will cause the
        current environment variables to be removed.
        """
        ...

    @typing.overload
    def __init__(self, other: "QProcessEnvironment") -> None:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#QProcessEnvironment-1

        **QProcessEnvironment::QProcessEnvironment(const QProcessEnvironment &
        other )**

        Creates a QProcessEnvironment object that is a copy of **other**.
        """
        ...

    def swap(self, other: "QProcessEnvironment") -> None:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#swap

        **[since 5.0] void QProcessEnvironment::swap(QProcessEnvironment & other
        )**

        Swaps this process environment instance with **other**. This function is
        very fast and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def keys(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#keys

        **QStringList QProcessEnvironment::keys() const**

        Returns a list containing all the variable names in this
        **QProcessEnvironment**  object.
        """
        ...

    @staticmethod
    def systemEnvironment() -> "QProcessEnvironment":
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#systemEnvironment

        **[static] QProcessEnvironment
        QProcessEnvironment::systemEnvironment()**

        The systemEnvironment function returns the environment of the calling
        process.

        It is returned as a **QProcessEnvironment** . This function does not
        cache the system environment. Therefore, it's possible to obtain an
        updated version of the environment if low-level C library functions like
        `setenv` or `putenv` have been called.

        However, note that repeated calls to this function will recreate the
        **QProcessEnvironment**  object, which is a non-trivial operation.

        **See also** **QProcess::systemEnvironment** ().
        """
        ...

    def toStringList(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#toStringList

        **QStringList QProcessEnvironment::toStringList() const**

        Converts this **QProcessEnvironment**  object into a list of strings,
        one for each environment variable that is set. The environment
        variable's name and its value are separated by an equal character ('=').

        The **QStringList**  contents returned by this function are suitable for
        presentation. Use with the QProcess::setEnvironment function is not
        recommended due to potential encoding problems under Unix, and worse
        performance.

        **See also** **systemEnvironment** (), **QProcess::systemEnvironment**
        (), and **QProcess::setProcessEnvironment** ().
        """
        ...

    def value(self, name: str, defaultValue: str = ...) -> str:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#value

        **QString QProcessEnvironment::value(const QString & name , const
        QString & defaultValue = QString()) const**

        Searches this **QProcessEnvironment**  object for a variable identified
        by **name** and returns its value. If the variable is not found in this
        object, then **defaultValue** is returned instead.

        **See also** **contains** (), **insert** (), and **remove** ().
        """
        ...

    def remove(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#remove

        **void QProcessEnvironment::remove(const QString & name )**

        Removes the environment variable identified by **name** from this
        **QProcessEnvironment**  object. If that variable did not exist before,
        nothing happens.

        **See also** **contains** (), **insert** (), and **value** ().
        """
        ...

    @typing.overload
    def insert(self, name: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#insert

        **void QProcessEnvironment::insert(const QString & name , const QString
        & value )**

        Inserts the environment variable of name **name** and contents **value**
        into this **QProcessEnvironment**  object. If that variable already
        existed, it is replaced by the new value.

        On most systems, inserting a variable with no contents will have the
        same effect for applications as if the variable had not been set at all.
        However, to guarantee that there are no incompatibilities, to remove a
        variable, please use the **remove** () function.

        **See also** **contains** (), **remove** (), and **value** ().
        """
        ...

    @typing.overload
    def insert(self, e: "QProcessEnvironment") -> None:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#insert-1

        **void QProcessEnvironment::insert(const QProcessEnvironment & e )**

        This is an overloaded function.

        Inserts the contents of **e** in this **QProcessEnvironment**  object.
        Variables in this object that also exist in **e** will be overwritten.
        """
        ...

    def contains(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#contains

        **bool QProcessEnvironment::contains(const QString & name ) const**

        Returns `true` if the environment variable of name **name** is found in
        this **QProcessEnvironment**  object.

        **See also** **insert** () and **value** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#clear

        **void QProcessEnvironment::clear()**

        Removes all key=value pairs from this **QProcessEnvironment**  object,
        making it empty.

        **See also** **isEmpty** () and **systemEnvironment** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qprocessenvironment.html#isEmpty

        **bool QProcessEnvironment::isEmpty() const**

        Returns `true` if this **QProcessEnvironment**  object is empty: that is
        there are no key=value pairs set.

        **See also** **clear** (), **systemEnvironment** (), and **insert** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtQuick import *
import enum


class QSGRendererInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsgrendererinterface.html

    **Detailed Description**

    Renderer interfaces allow accessing graphics API specific functionality in
    the scenegraph. Such internals are not typically exposed. However, when
    integrating custom rendering via **QSGRenderNode**  for example, it may
    become necessary to query certain values, for instance the graphics device
    (e.g. the Direct3D or Vulkan device) that is used by the scenegraph.

    QSGRendererInterface's functions have varying availability. API and language
    queries, such as, **graphicsApi** () or **shaderType** () are always
    available, meaning it is sufficient to construct a **QQuickWindow**  or
    **QQuickView** , and the graphics API or shading language in use can be
    queried right after via **QQuickWindow::rendererInterface** (). This
    guarantees that utilities like the **GraphicsInfo**  QML type are able to
    report the correct values as early as possible, without having conditional
    property values - depending on for instance **shaderType** () - evaluate to
    unexpected values.

    Engine-specific accessors, like **getResource** (), are however available
    only after the scenegraph is initialized. Additionally, there may be
    backend-specific limitations on when such functions can be called. The only
    way that is guaranteed to succeed is calling them when the rendering of a
    node (i.e. the preparation of the command list for the next frame) is
    active. In practice this typically means **QSGRenderNode::render** ().
    """

    class RenderMode(enum.Enum):
        RenderMode2D: QSGRendererInterface = ...
        RenderMode2DNoDepthBuffer: QSGRendererInterface = ...
        RenderMode3D: QSGRendererInterface = ...

    class ShaderSourceType(enum.Flag):
        ShaderSourceString: QSGRendererInterface = ...
        ShaderSourceFile: QSGRendererInterface = ...
        ShaderByteCode: QSGRendererInterface = ...

    class ShaderCompilationType(enum.Flag):
        RuntimeCompilation: QSGRendererInterface = ...
        OfflineCompilation: QSGRendererInterface = ...

    class ShaderType(enum.Enum):
        UnknownShadingLanguage: QSGRendererInterface = ...
        GLSL: QSGRendererInterface = ...
        HLSL: QSGRendererInterface = ...
        RhiShader: QSGRendererInterface = ...

    class Resource(enum.Enum):
        DeviceResource: QSGRendererInterface = ...
        CommandQueueResource: QSGRendererInterface = ...
        CommandListResource: QSGRendererInterface = ...
        PainterResource: QSGRendererInterface = ...
        RhiResource: QSGRendererInterface = ...
        PhysicalDeviceResource: QSGRendererInterface = ...
        OpenGLContextResource: QSGRendererInterface = ...
        DeviceContextResource: QSGRendererInterface = ...
        CommandEncoderResource: QSGRendererInterface = ...
        VulkanInstanceResource: QSGRendererInterface = ...
        RenderPassResource: QSGRendererInterface = ...
        RhiSwapchainResource: QSGRendererInterface = ...
        RhiRedirectCommandBuffer: QSGRendererInterface = ...
        RhiRedirectRenderTarget: QSGRendererInterface = ...

    class GraphicsApi(enum.Enum):
        Unknown: QSGRendererInterface = ...
        Software: QSGRendererInterface = ...
        OpenGL: QSGRendererInterface = ...
        OpenVG: QSGRendererInterface = ...
        OpenGLRhi: QSGRendererInterface = ...
        Direct3D11Rhi: QSGRendererInterface = ...
        VulkanRhi: QSGRendererInterface = ...
        MetalRhi: QSGRendererInterface = ...
        NullRhi: QSGRendererInterface = ...
        Direct3D11: QSGRendererInterface = ...
        Vulkan: QSGRendererInterface = ...
        Metal: QSGRendererInterface = ...
        Null: QSGRendererInterface = ...

    @staticmethod
    def isApiRhiBased(api: "QSGRendererInterface.GraphicsApi") -> bool:
        """
        https://doc.qt.io/qt-6/qsgrendererinterface.html#isApiRhiBased

        **[static, since 5.14] bool
        QSGRendererInterface::isApiRhiBased(QSGRendererInterface::GraphicsApi
        api )**

        Returns true if **api** is based on a graphics abstraction layer (QRhi)
        instead of directly calling the native graphics API.

        **Note:** This function can be called on any thread.

        This function was introduced in Qt 5.14.
        """
        ...

    def shaderSourceType(self) -> "QSGRendererInterface.ShaderSourceType":
        """
        https://doc.qt.io/qt-6/qsgrendererinterface.html#shaderSourceType

        **[pure virtual] QSGRendererInterface::ShaderSourceTypes
        QSGRendererInterface::shaderSourceType() const**

        Returns a bitmask of the supported ways of providing shader sources in
        **ShaderEffect**  items.

        **Note:** This function can be called on any thread.

        **See also** **QtQuick::GraphicsInfo** .
        """
        ...

    def shaderCompilationType(self) -> "QSGRendererInterface.ShaderCompilationType":
        """
        https://doc.qt.io/qt-6/qsgrendererinterface.html#shaderCompilationType

        **[pure virtual] QSGRendererInterface::ShaderCompilationTypes
        QSGRendererInterface::shaderCompilationType() const**

        Returns a bitmask of the shader compilation approaches supported by the
        Qt Quick backend the application is using.

        **Note:** This function can be called on any thread.

        **See also** **QtQuick::GraphicsInfo** .
        """
        ...

    def shaderType(self) -> "QSGRendererInterface.ShaderType":
        """
        https://doc.qt.io/qt-6/qsgrendererinterface.html#shaderType

        **[pure virtual] QSGRendererInterface::ShaderType
        QSGRendererInterface::shaderType() const**

        Returns the shading language supported by the Qt Quick backend the
        application is using.

        **Note:** This function can be called on any thread.

        **See also** **QtQuick::GraphicsInfo** .
        """
        ...

    @typing.overload
    def getResource(
        self, window: QQuickWindow, resource: "QSGRendererInterface.Resource"
    ) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsgrendererinterface.html#getResource

        **[virtual] void *QSGRendererInterface::getResource(QQuickWindow *
        window , QSGRendererInterface::Resource resource ) const**

        Queries a graphics **resource** in **window**. Returns null when the
        resource in question is not supported or not available.

        When successful, the returned pointer is either a direct pointer to an
        interface, or a pointer to an opaque handle that needs to be
        dereferenced first (for example, `VkDevice dev = *static_cast<VkDevice
        \\*>(result)`). The latter is necessary since such handles may have sizes
        different from a pointer.

        **Note:** The ownership of the returned pointer is never transferred to
        the caller.

        **Note:** This function must only be called on the render thread.
        """
        ...

    @typing.overload
    def getResource(self, window: QQuickWindow, resource: str) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsgrendererinterface.html#getResource-1

        **[virtual] void *QSGRendererInterface::getResource(QQuickWindow *
        window , const char * resource ) const**

        Queries a graphics resource. **resource** is a backend-specific key.
        This allows supporting any future resources that are not listed in the
        Resource enum.

        **Note:** The ownership of the returned pointer is never transferred to
        the caller.

        **Note:** This function must only be called on the render thread.
        """
        ...

    def graphicsApi(self) -> "QSGRendererInterface.GraphicsApi":
        """
        https://doc.qt.io/qt-6/qsgrendererinterface.html#graphicsApi

        **[pure virtual] QSGRendererInterface::GraphicsApi
        QSGRendererInterface::graphicsApi() const**

        Returns the graphics API that is in use by the Qt Quick scenegraph.

        **Note:** This function can be called on any thread.
        """
        ...
